<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://estatebud.com
 * @since      1.0.0
 *
 * @package    Estatebud
 * @subpackage Estatebud/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Estatebud
 * @subpackage Estatebud/admin
 * @author     Estatebud
 */
class Estatebud_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $id    The ID of this plugin.
	 */
	private $id;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since      1.0.0
	 * @param      string    $id         The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($id, $version)
	{

		$this->id = $id;
		$this->version = $version;

		add_action('admin_menu', array($this, 'create_admin_settings_page'));
		add_filter('parent_file', array($this, 'estatebud_parent_file'));

		add_action("wp_ajax_estatebud_get_listing", array($this, "estatebud_get_listing"));
		add_action("wp_ajax_nopriv_estatebud_get_listing", array($this, "estatebud_get_listing"));

		add_action("wp_ajax_estatebud_get_listing_map", array($this, "estatebud_get_listing_map"));
		add_action("wp_ajax_nopriv_estatebud_get_listing_map", array($this, "estatebud_get_listing_map"));

		add_action("wp_ajax_estatebud_get_infowindow", array($this, "estatebud_get_infowindow"));
		add_action("wp_ajax_nopriv_estatebud_get_infowindow", array($this, "estatebud_get_infowindow"));

		add_action("wp_ajax_estatebud_send_contact", array($this, "estatebud_send_contact"));
		add_action("wp_ajax_nopriv_estatebud_send_contact", array($this, "estatebud_send_contact"));

		if (isset($_GET["tab"]) && $_GET["tab"] == "email-settings") {
			add_filter('tiny_mce_before_init', array($this, 'estatebud_override_mce_options'));
		}
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{
		wp_enqueue_style($this->id, plugin_dir_url(__FILE__) . 'css/estatebud-admin.css', array(), $this->version, 'all');
		wp_enqueue_style("jquery-sumoselect", plugin_dir_url(__FILE__) . '../public/css/sumoselect.css', array(), $this->version, 'all');
		if (isset($_GET["page"]) && $_GET["page"] == "estatebud_settings" && isset($_GET["tab"]) && $_GET["tab"] == "plugin-settings") {
			wp_enqueue_style('wp-color-picker');
		}
		if (isset($_GET["page"]) && $_GET["page"] == "estatebud_settings" && isset($_GET["tab"]) && ($_GET["tab"] == "shortcodes" || $_GET["tab"] == "widgets")) {
			wp_enqueue_style("bootstrap", plugin_dir_url(__FILE__) . 'css/grid.min.css', array(), $this->version, 'all');
		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{
		add_thickbox();

		wp_enqueue_script($this->id, plugin_dir_url(__FILE__) . 'js/estatebud-admin.js', array('jquery'), $this->version, false);
		wp_enqueue_script("jquery-sumoselect", plugin_dir_url(__FILE__) . '../public/js/sumoselect.full.min.js', array('jquery'), $this->version, false);

		if (isset($_GET["page"]) && $_GET["page"] == "estatebud_settings" && isset($_GET["tab"]) && $_GET["tab"] == "shortcodes") {
			wp_localize_script($this->id, 'estatebudL10n', array(
				'error' => __("Error: ", "estatebud"),
				'edit_form_title' => __('Edit Existing Shortcode', "estatebud"),
				'edit_form_button' => __('Save Shortcode', "estatebud"),
				'new_form_title' => __('Create New Shortcode', "estatebud"),
				'new_form_button' => __('Create Shortcode', "estatebud"),
				'new_form_security' => wp_create_nonce("estatebud_save_shortcode", "shortcode_security"),
				'edit_form_security' => wp_create_nonce("estatebud_edit_shortcode", "shortcode_security")
			));
		} else if (isset($_GET["page"]) && $_GET["page"] == "estatebud_settings" && isset($_GET["tab"]) && $_GET["tab"] == "widgets") {
			wp_enqueue_script('ace_code_highlighter_js', plugin_dir_url(__FILE__) . 'js/ace.js', '', '1.0.0', true);
			wp_enqueue_script('ace_mode_js', plugin_dir_url(__FILE__) . 'js/mode-html.js', array('ace_code_highlighter_js'), '1.0.0', true);
			wp_localize_script($this->id, 'estatebudL10n', array(
				'error' => __("Error: ", "estatebud"),
				'edit_form_title' => __('Edit Existing Widget', "estatebud"),
				'edit_form_button' => __('Save Widget', "estatebud"),
				'new_form_title' => __('Create New Widget', "estatebud"),
				'new_form_button' => __('Create Widget', "estatebud"),
				'new_form_security' => wp_create_nonce("estatebud_save_widget", "widget_security"),
				'edit_form_security' => wp_create_nonce("estatebud_edit_widget", "widget_security")
			));
		} else if (isset($_GET["page"]) && $_GET["page"] == "estatebud_settings" && isset($_GET["tab"]) && $_GET["tab"] == "plugin-settings") {
			wp_enqueue_script('wp-color-picker');
			wp_enqueue_script('ace_code_highlighter_js', plugin_dir_url(__FILE__) . 'js/ace.js', '', '1.0.0', true);
			wp_enqueue_script('ace_mode_js', plugin_dir_url(__FILE__) . 'js/mode-css.js', array('ace_code_highlighter_js'), '1.0.0', true);
		}
	}

	/**
	 * Creating the settings page
	 *
	 * @since    1.0.0
	 */
	public function create_admin_settings_page()
	{

		global $available_pages;

		$available_pages = [
			["slug" => "welcome", "title" => __("Welcome", "estatebud"), "extra_classes" => "nav-tab-estatebud-welcome", "icon" => "dashicons dashicons-admin-home"],
			["slug" => "plugin-settings", "title" => __("Plugin Settings", "estatebud"), "extra_classes" => "nav-tab-estatebud-plugin-settings", "icon" => "dashicons dashicons-admin-tools"],
			["slug" => "api-settings", "title" => __("API Settings", "estatebud"), "extra_classes" => "nav-tab-estatebud-api", "icon" => "dashicons dashicons-admin-generic"],
			["slug" => "pdf-settings", "title" => __("PDF Brochure", "estatebud"), "extra_classes" => "nav-tab-estatebud-pdf-settings", "icon" => "dashicons dashicons-media-document"],
			["slug" => "listing-settings", "title" => __("Listing Settings", "estatebud"), "extra_classes" => "nav-tab-estatebud-api", "icon" => "dashicons dashicons-exerpt-view"],
			["slug" => "maps", "title" => __("Interactive Maps", "estatebud"), "extra_classes" => "nav-tab-estatebud-widgets", "icon" => "dashicons dashicons-location-alt"],
			["slug" => "property-inquiries", "title" => __("Property Inquiries", "estatebud"), "extra_classes" => "nav-tab-estatebud-email", "icon" => "dashicons dashicons-email"],
			["slug" => "shortcodes", "title" => __("Shortcodes", "estatebud"), "extra_classes" => "nav-tab-estatebud-shortcodes", "icon" => "dashicons dashicons-welcome-view-site"],
			["slug" => "widgets", "title" => __("Search Boxes", "estatebud"), "extra_classes" => "nav-tab-estatebud-widgets", "icon" => "dashicons dashicons-search"],
			["slug" => "support", "title" => __("Support", "estatebud"), "extra_classes" => "nav-tab-estatebud-support", "icon" => "dashicons dashicons-sos"]
		];
		add_menu_page(
			__('Estatebud Settings', "estatebud"),			// The title to be displayed in the browser window for this page.
			__('Estatebud', "estatebud"),					// The text to be displayed for this menu item
			'administrator',								// Which type of users can see this menu item
			'estatebud_settings',							// The unique ID - that is, the slug - for this menu item
			array($this, 'estatebud_settings_page'),		// The name of the function to call when rendering this menu's page
			plugin_dir_url(__FILE__) . "assets/estatebud.svg"  // The icon path
		);
		foreach ($available_pages as $available_page) {
			add_submenu_page('estatebud_settings', $available_page["title"], $available_page["title"], "administrator", "admin.php?page=estatebud_settings&tab=" . $available_page["slug"]);
		}
		remove_submenu_page('estatebud_settings', 'estatebud_settings');
	}

	/**
	 * Fix for active class selection on the submenu pages
	 *
	 * @param    $parent_file
	 * @return   void
	 * @since 	 1.0.0
	 */
	function estatebud_parent_file($parent_file)
	{
		global $submenu_file, $available_pages;
		foreach ($available_pages as $available_page) {
			if (isset($_GET['tab']) && $_GET['tab'] == $available_page["slug"]) {
				$submenu_file = 'admin.php?page=estatebud_settings&tab=' . $available_page["slug"];
				break;
			}
		}
		return $parent_file;
	}

	/**
	 * Display admin settings page
	 *
	 * @since    1.0.0
	 */
	public function estatebud_settings_page()
	{
		require_once dirname(__FILE__) . "/partials/estatebud-admin-display.php";
	}

	function estatebud_override_mce_options($initArray)
	{
		if (substr($initArray["selector"], 1, 9) == "estatebud") {
			$opts = '*[*]';
			$initArray['valid_elements'] = $opts;
			$initArray['extended_valid_elements'] = $opts;
			$initArray['remove_linebreaks'] = false;
			$initArray['remove_redundant_brs'] = false;
			$initArray['wpautop'] = false;
			return $initArray;
		}
	}

	/**
	 * Public AJAX callback to fetch property list
	 *
	 * @return void
	 */
	public function estatebud_get_listing()
	{
		check_ajax_referer("estatebud_get_listing", "security");

		$api_key = get_option("estatebud_api_key", null);
		$estatebud_api = new EstatebudAPI($api_key, isset($_GET["lang"]) ? $_GET["lang"] : get_locale());
		$data = $_GET;

		// fixes for empty selectboxes
		if (!isset($data["category"])) $data["category"] = [];
		if (!isset($data["status"])) $data["status"] = [];
		if (!isset($data["area"])) $data["area"] = [];
		if (!isset($data["type"])) $data["type"] = [];

		if (isset($data["budget_min"])) $data["price_min"] = intval($data["budget_min"]);
		if (isset($data["budget_max"]))	$data["price_max"] = intval($data["budget_max"]);
		if (isset($data["price_min"])) $data["rent_min"] = intval($data["price_min"]);
		if (isset($data["price_max"])) $data["rent_max"] = intval($data["price_max"]);

		// fix area array
		$has_linked_areas = false;
		if (isset($data["area_4"]) && count($data["area_4"]) > 0){
			$has_linked_areas = true;
			$area4 = array_map(function($d) { return explode('^', $d); }, $data["area_4"]);
			$level4_parents = array_column($area4, 0);
			$level4_ids = array_column($area4, 1);
		}else{
			$level4_ids = [];
			$level4_parents = [];
		}

		if (isset($data["area_3"]) && count($data["area_3"]) > 0){
			$has_linked_areas = true;
			$area3 = array_map(function($d) { return explode('^', $d); }, $data["area_3"]);
			$level3_parents = array_column($area3, 0);
			$level3_ids = array_diff(array_column($area3, 1), $level4_parents);
		}else{
			$level3_ids = [];
			$level3_parents = [];
		}

		if (isset($data["area_2"]) && count($data["area_2"]) > 0){
			$has_linked_areas = true;
			$area2 = array_map(function($d) { return explode('^', $d); }, $data["area_2"]);
			$level2_parents = array_column($area2, 0);
			$level2_ids = array_diff(array_column($area2, 1), $level3_parents);
		}else{
			$level2_ids = [];
			$level2_parents = [];
		}

		if (isset($data["area_1"]) && count($data["area_1"]) > 0){
			$has_linked_areas = true;
			$level1_ids = array_diff($data["area_1"], $level2_parents);
		}else{
			$level1_ids = [];
		}
		if($has_linked_areas) {
			$data["area"] = array_merge($level2_ids, $level3_ids, $level4_ids);
		}

		if (isset($data["sort"]) && strpos($data["sort"], "|") > 0) {
			$sorters = explode("|", $data["sort"]);
			$data["sort"] = $sorters[0];
			$data["sort_type"] = strtoupper($sorters[1]);
		}

		$shortcode_key = $_SERVER["HTTP_ESTATEBUD_SHORTCODE"];
		if ($shortcode_key) {
			$shortcodes = get_option("estatebud_shortcode_settings", []);
			if (count($shortcodes) && isset($shortcodes[$shortcode_key])) {
				$data = array_merge($shortcodes[$shortcode_key], $data);
			}
		}

		$estatebud_list = $this->call_user_func_assoc_array(array($estatebud_api, "get_properties"), $data);
		require_once dirname(__FILE__) . "/../public/partials/estatebud-public-listing-properties.php";

		wp_die();
	}

	/**
	 * Public AJAX callback to fetch property list for map
	 *
	 * @return void
	 */
	public function estatebud_get_listing_map()
	{
		//$time2 = microtime(true);

		check_ajax_referer("estatebud_get_listing_map", "security");

		$api_key = get_option("estatebud_api_key", null);

		$estatebud_api = new EstatebudAPI($api_key, isset($_GET["lang"]) ? $_GET["lang"] : get_locale());
		$data = $_GET;

		if (!isset($data["category"])) $data["category"] = [];
		if (!isset($data["status"])) $data["status"] = [];
		if (!isset($data["area"])) $data["area"] = [];
		if (!isset($data["type"])) $data["type"] = [];

		// fix area array
		$has_linked_areas = false;
		if (isset($data["area_4"]) && count($data["area_4"]) > 0){
			$has_linked_areas = true;
			$area4 = array_map(function($d) { return explode('^', $d); }, $data["area_4"]);
			$level4_parents = array_column($area4, 0);
			$level4_ids = array_column($area4, 1);
		}else{
			$level4_ids = [];
			$level4_parents = [];
		}

		if (isset($data["area_3"]) && count($data["area_3"]) > 0){
			$has_linked_areas = true;
			$area3 = array_map(function($d) { return explode('^', $d); }, $data["area_3"]);
			$level3_parents = array_column($area3, 0);
			$level3_ids = array_diff(array_column($area3, 1), $level4_parents);
		}else{
			$level3_ids = [];
			$level3_parents = [];
		}

		if (isset($data["area_2"]) && count($data["area_2"]) > 0){
			$has_linked_areas = true;
			$area2 = array_map(function($d) { return explode('^', $d); }, $data["area_2"]);
			$level2_parents = array_column($area2, 0);
			$level2_ids = array_diff(array_column($area2, 1), $level3_parents);
		}else{
			$level2_ids = [];
			$level2_parents = [];
		}

		if (isset($data["area_1"]) && count($data["area_1"]) > 0){
			$has_linked_areas = true;
			$level1_ids = array_diff($data["area_1"], $level2_parents);
		}else{
			$level1_ids = [];
		}
		if($has_linked_areas) {
			$data["area"] = array_merge($level2_ids, $level3_ids, $level4_ids);
		}

		if (isset($data["sort"]) && strpos($data["sort"], "|") > 0) {
			$sorters = explode("|", $data["sort"]);
			$data["sort"] = $sorters[0];
			$data["sort_type"] = strtoupper($sorters[1]);
		}

		$shortcode_key = $_SERVER["HTTP_ESTATEBUD_SHORTCODE"];

		if ($shortcode_key) {
			$shortcodes = get_option("estatebud_shortcode_settings", []);
			if (count($shortcodes) && isset($shortcodes[$shortcode_key])) {
				$data = array_merge($shortcodes[$shortcode_key], $data);
			}
		}

		$current_limit = $data["limit"];
		$current_offset = $data["offset"];

		$data["limit"] = 9999;
		$data["offset"] = 0;

		//$time = microtime(true);
		$estatebud_data = $this->call_user_func_assoc_array(array($estatebud_api, "get_properties"), $data);

		// var_dump($estatebud_data);

		//error_log("Received Data in " . (microtime(true) - $time) . " seconds");
		//$time = microtime(true);

		$filtering = $estatebud_data;
		$estatebud_filtered = $this->estatebud_filter_data($filtering);

		//error_log("Filtered data in " . (microtime(true) - $time) . " seconds");
		//$time = microtime(true);

		$paginating = $estatebud_data;
		$estatebud_list = $this->estatebud_paginate_data($paginating, $current_offset, $current_limit);

		//error_log("Paginated data in " . (microtime(true) - $time) . " seconds");
		//$time = microtime(true);

		ob_start();
		if(isset($_GET["is_listing_map"])){
			require_once dirname(__FILE__) . "/../public/partials/estatebud-public-listing-properties.php";
		}else{
			require_once dirname(__FILE__) . "/../public/partials/estatebud-public-map-sidebar.php";
		}
		$output = ob_get_clean();

		//error_log("Created list in " . (microtime(true) - $time) . " seconds");
		$time = microtime(true);

		echo json_encode([
			"html" => $output,
			"data" => $estatebud_filtered
		]);

		//error_log("Output printed in " . (microtime(true) - $time) . " seconds");
		//error_log("All run in " . (microtime(true) - $time2) . " seconds");
		wp_die();
	}

	public function estatebud_get_infowindow()
	{
		check_ajax_referer("estatebud_get_infowindow", "security");
		$api_key = get_option("estatebud_api_key", null);

		$estatebud_api = new EstatebudAPI($api_key, isset($_GET["lang"]) ? $_GET["lang"] : get_locale());
		$ids = array_filter(array_unique(explode(",", $_GET["id"])), function($id){ return intval($id) != 0; });

		if(count($ids) > 1){
			echo "<div class='estatebud-infowindow-slider'>";
		}

		$data = [
			"id" => implode(",", $ids),
			"limit" => count($ids),
			"offset" => 0
		];

		$properties = $this->call_user_func_assoc_array(array($estatebud_api, "get_properties"), $data);

		// die(var_dump($properties));

		if(property_exists($properties, "results")){
			foreach($ids as $key => $id){
				$id = intval($id);
				$result = $properties->results->$id;
				if($result){
					echo $this->estatebud_create_infowindow($estatebud_api, $result);
				}
				else {
					$ids[$key] = null;
				}
			}
		}else{
			$ids = [];
		}

		$ids = array_filter($ids);

		if(count($ids) > 1){
			$string = estatebud__('app.x.of.x.properties');
			$string = str_replace('%1$d', "<span class='estatebud-infowindow-current'></span>", $string);
			$string = str_replace('%2$d', "<span class='estatebud-infowindow-total'></span>", $string);
			echo "</div><div class='estatebud-infowindow-footer'>
				<div class='estatebud-left-arrow'><i class='fa fa-chevron-left'></i></div>
				<div class='estatebud-infowindow-count'>$string</div>
				<div class='estatebud-right-arrow'><i class='fa fa-chevron-right'></i></div>
			</div>";
		}

		wp_die();
	}

	private function estatebud_paginate_data($details, $offset, $limit)
	{
		$paginated_results = [];
		$results = array_values((array)$details->results);
		$count = count($results);
		for ($i = $offset; $i < $limit + $offset; $i++) {
			if ($i < $count) $paginated_results[] = $results[$i];
		}
		$details->results = $paginated_results;
		return $details;
	}

	private function estatebud_filter_data($details)
	{
		$results = [];
		foreach ($details->results as $detail) {
			$data = new stdClass();
			$data->id = $detail->id;
			$data->location_lat = $detail->location_lat;
			$data->location_lng = $detail->location_lng;
			$data->category = property_exists($detail, "category") ? $detail->category : "";
			$data->type = property_exists($detail, "type") ? $detail->type->value : "";
			$results[] = $data;
		}
		return $results;
	}

	private function estatebud_create_infowindow($estatebud_api, $data)
	{
		require_once dirname(__FILE__) . "/../public/partials/estatebud-public-details-functions.php";

		$output = '<div class="estatebud-map-marker"><div class="estatebud-listing"><div class="estatebud-infowindow-close"><i class="fa fa-times"></i></div>';
		$output .= estatebud_generate_property_list_entry($estatebud_api, $data, array("open_new_tab" => true));
		$output .= '</div></div>';

		return $output;
	}


	private function call_user_func_assoc_array($callback, $args)
	{
		$ref = new ReflectionMethod(get_class($callback[0]), $callback[1]);
		$parameters = $ref->getParameters();
		$params = [];
		foreach ($parameters as $parameter) {
			$param_name = $parameter->getName();
			$params[$param_name] = isset($args[$param_name]) ? $args[$param_name] : $parameter->getDefaultValue();
			if (is_array($params[$param_name])) $params[$param_name] = implode(",", $params[$param_name]);
		}
		return call_user_func_array($callback, $params);
	}

	/**
	 * Public AJAX callback to do contact form actions
	 *
	 * @return void
	 */
	public function estatebud_send_contact()
	{
		remove_filter('wp_mail', 'wp_staticize_emoji_for_email');
		check_ajax_referer("estatebud_send_contact", "contact_security");

		$use_recaptcha = get_option("estatebud_use_recaptcha", false);
		$pp_url = trim(get_option("estatebud_email_privacy_policy_url", ""));
		$pp_url = empty($pp_url) ? false : $pp_url;
		$site_key = get_option("recaptcha_sitekey_value", false);
		$site_secret = get_option("estatebud_gcaptcha_secret", false);
		$site_key_v3 = get_option("recaptcha3_sitekey_value", false);
		$site_secret_v3 = get_option("estatebud_gcaptcha3_secret", false);
		$email_sender_name = get_option("estatebud_email_sender_name", false);
		$email_sender_address = get_option("estatebud_email_sender_address", false);

		$placeholders = array(
			"%name%",
			"%email%",
			"%phone%",
			"%property_id%",
			"%reference_id%",
			"%website_url%",
			"%website_name%",
			"%message%",
			"%timestamp%",
			"%footer_text%",
			"%company_info%"
		);

		$placeholders_values = array(
			sanitize_text_field($_POST["name"]),
			sanitize_email($_POST["email"]),
			sanitize_text_field($_POST["phone"]),
			sanitize_text_field($_POST["property_id"]),
			sanitize_text_field($_POST["reference_id"]),
			sanitize_text_field(home_url()),
			sanitize_text_field(get_bloginfo("site_name")),
			sanitize_textarea_field($_POST["message"]),
			current_time('mysql'),
			get_option("estatebud_email_footer_line"),
			get_option("estatebud_email_company_line")
		);

		if ($pp_url && !isset($_POST["estatebud-privacy-policy-accepted"])) {
			wp_die(json_encode([
				"status" => "error",
				"message" => __("Please indicate that you have read and agreed to the Privacy Policy", "estatebud")
			]));
		}

		if ($use_recaptcha) {
			if (!empty($site_secret_v3) && !empty($site_key_v3)) {
				if ($this->verify_google_captcha($_POST["g-recaptcha-response"], $site_secret_v3) === false) {
					wp_die(json_encode([
						"status" => "error",
						"message" => __("The Google reCAPTCHAv3 verification failed. Please try again.", "estatebud")
					]));
				}
			} else {
				if (empty($site_secret) || empty($site_key)) {
					wp_die(json_encode([
						"status" => "error",
						"message" => __("The Google reCAPTCHA is not installed. Please contact Site Administrator.", "estatebud")
					]));
				} else {
					if ($this->verify_google_captcha($_POST["g-recaptcha-response"], $site_secret) === false) {
						wp_die(json_encode([
							"status" => "error",
							"message" => __("The Google reCAPTCHA verification failed. Please try again.", "estatebud")
						]));
					}
				}
			}
		}

		// send user mail
		$to = sanitize_email($_POST['email']);
		$subject = str_replace($placeholders, $placeholders_values, get_option("estatebud_email_user_subject", null));
		$body = str_replace($placeholders, $placeholders_values, get_option("estatebud_email_template_user", null));
		$body = "<style>.aligncenter { margin: 0 auto; text-align: center; }</style>" . $body;
		$headers = array('Content-Type: text/html; charset=UTF-8');

		if ($email_sender_name && $email_sender_address && !empty($email_sender_name) && !empty($email_sender_address) && is_email($email_sender_address)) {
			$headers[] = 'From: ' . $email_sender_name . ' <' . $email_sender_address . '>';
		}

		$result = wp_mail($to, $subject, $body, $headers);

		if ($result && get_option("estatebud_email_to_company_enabled", true)) {
			// send company mail
			$to = [sanitize_email(get_bloginfo("admin_email"))];
			$others = array_map("trim", explode(";", get_option("estatebud_email_company_recipient")));
			foreach ($others as $other) {
				$to[] = sanitize_email($other);
			}
			$to = array_unique($to);
			$subject = str_replace($placeholders, $placeholders_values, get_option("estatebud_email_company_subject", null));
			$body = str_replace($placeholders, $placeholders_values, get_option("estatebud_email_template_contact", null));
			$body = "<style>.aligncenter { margin: 0 auto; text-align: center; }</style>" . $body;
			$headers = array('Content-Type: text/html; charset=UTF-8');

			if ($email_sender_name && $email_sender_address && !empty($email_sender_name) && !empty($email_sender_address) && is_email($email_sender_address)) {
				$headers[] = 'From: ' . $email_sender_name . ' <' . $email_sender_address . '>';
			}

			$result = wp_mail($to, $subject, $body, $headers);
		}

		if(get_option("estatebud_save_to_crm_deal", false) == true)
		{
			$api_key = get_option("estatebud_api_key", null);
			$estatebud_api = new EstatebudAPI($api_key, isset($_GET["lang"]) ? $_GET["lang"] : get_locale());

			$pipeline_id = get_option("estatebud_crm_pipeline_id", -1);
			$stage_id = get_option("estatebud_crm_stage_id", -1);
			$name = sanitize_text_field($_POST["name"]);
			$email =sanitize_email($_POST["email"]);
			$phone = sanitize_text_field($_POST["phone"]);
			$property_id = sanitize_text_field($_POST["property_id"]);
			$note = sanitize_textarea_field($_POST["message"]);
			$currency = isset($_POST["currency"]) ? sanitize_text_field($_POST["currency"]) : '';
			$price = isset($_POST["price"]) ? sanitize_text_field($_POST["price"]) : '';
			$estatebud_api->new_deal($pipeline_id, $stage_id, $name, $email, $phone, $property_id, $note, $currency, $price);
		}

		if ($result) {
			echo json_encode(["status" => "success", "message" => __("Your contact request is successfully sent. We will respond to it as soon as we receive the details. Thank you for contacting us.", "estatebud")]);
		} else {
			echo json_encode(["status" => "error", "message" => __("Oops! Something went wrong. Please try again.", "estatebud")]);
		}
		wp_die();
	}

	private function verify_google_captcha($gcaptcha_response, $secret)
	{
		//open a new curl connection
		$ch = curl_init();
		$url = "https://www.google.com/recaptcha/api/siteverify";
		$args = array(
			'method' => 'POST',
			'timeout' => 45,
			'body' => array(
				"secret" => $secret,
				"response" => $gcaptcha_response,
			)
		);
		$response = wp_remote_post($url, $args);
		$response_code = wp_remote_retrieve_response_code($response);
		if ($response_code == 200) {
			$body = wp_remote_retrieve_body($response);
			$json_data = json_decode($body);
			if (!$json_data || $json_data->success == false) {
				return false;
			}
			return true;
		} else {
			return false;
		}
	}
}