<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       http://estatebud.com
 * @since      1.0.0
 *
 * @package    Estatebud
 * @subpackage Estatebud/admin/partials
 */

if (!isset($estatebud_api)) return;

if(isset($_POST["clear_cache"])){
    global $wpdb;
    $prefix = $wpdb->prefix;
    $wpdb->query("DELETE from {$prefix}options where option_name like 'cache_estatebud_%'");
    // clear other posted data to prevent changes, only submit button will change them.
    $_POST = [];
}

if (isset($_POST['estatebud_api_key'])) {
    $estatebud_api_key = sanitize_text_field($_POST['estatebud_api_key']);
    update_option('estatebud_api_key', $estatebud_api_key);
} else {
    $estatebud_api_key = get_option("estatebud_api_key", "");
}

$estatebud_api = new EstatebudAPI($estatebud_api_key, get_locale());

if (isset($_POST['estatebud_gmaps_api_key'])) {
    $gmaps_value = sanitize_text_field($_POST['estatebud_gmaps_api_key']);
    update_option('estatebud_gmaps_api_key', $gmaps_value);
} else {
    $gmaps_value = get_option("estatebud_gmaps_api_key", "");
}

if(isset($_POST["estatebud_api_key"])){
    $use_recaptcha = isset($_POST['estatebud_use_recaptcha']);
    update_option('estatebud_use_recaptcha', $use_recaptcha);
}else{
    $use_recaptcha = get_option('estatebud_use_recaptcha', false);
}

if (isset($_POST['recaptcha3_sitekey_value'])) {
    $recaptcha3_sitekey_value = sanitize_text_field($_POST['recaptcha3_sitekey_value']);
    update_option('recaptcha3_sitekey_value', $recaptcha3_sitekey_value);
} else {
    $recaptcha3_sitekey_value = esc_attr(get_option("recaptcha3_sitekey_value", ""));
}

if (isset($_POST['estatebud_gcaptcha3_secret'])) {
    $estatebud_gcaptcha3_secret = sanitize_text_field($_POST['estatebud_gcaptcha3_secret']);
    update_option('estatebud_gcaptcha3_secret', $estatebud_gcaptcha3_secret);
} else {
    $estatebud_gcaptcha3_secret = esc_attr(get_option("estatebud_gcaptcha3_secret", ""));
}

if (isset($_POST['recaptcha_sitekey_value'])) {
    $recaptcha_sitekey_value = sanitize_text_field($_POST['recaptcha_sitekey_value']);
    update_option('recaptcha_sitekey_value', $recaptcha_sitekey_value);
} else {
    $recaptcha_sitekey_value = esc_attr(get_option("recaptcha_sitekey_value", ""));
}

if (isset($_POST['estatebud_gcaptcha_secret'])) {
    $estatebud_gcaptcha_secret = sanitize_text_field($_POST['estatebud_gcaptcha_secret']);
    update_option('estatebud_gcaptcha_secret', $estatebud_gcaptcha_secret);
} else {
    $estatebud_gcaptcha_secret = esc_attr(get_option("estatebud_gcaptcha_secret", ""));
}

?>
<form method="post">
    <table class="form-table">
        <tr valign="top">
            <th scope="row"><?php _e("Estatebud API Key", "estatebud");?></th>
            <td><input type="text" name="estatebud_api_key" class="estatebud-api-key-input" value="<?php echo $estatebud_api_key; ?>" /></td>
        </tr>
        <?php if ($estatebud_api_key != "") {
            if ($estatebud_api->check_authentication()) { ?>
        <tr valign="top">
            <th scope="row"></th>
            <td>
                <b><?php echo __("Company Name", "estatebud") . "</b>: " . $estatebud_api->auth_info->company_name ?><br>
                <b><?php echo __("Company Domain", "estatebud") . "</b>: " . $estatebud_api->auth_info->company_domain ?><br>
                <b><?php echo __("Hash", "estatebud") . "</b>: " . $estatebud_api->auth_info->hash ?><br>
                <b><?php echo __("Currency", "estatebud") . "</b>: " . $estatebud_api->auth_info->currency ?><br>
                <b><?php echo __("Unit of Measurement", "estatebud") . "</b>: " . $estatebud_api->auth_info->measurements ?><br><br>
            </td>
        </tr>
            <?php
        } else { ?>
        <tr valign="top">
            <th scope="row"></th>
            <td><?php echo __("Invalid API Key", "estatebud"); ?></td>
        </tr>
            <?php
        }
    } ?>
        <tr style="border-top: 1px solid #eee;"><td colspan="2">&nbsp;</td></tr>
        <tr valign="top">
            <th scope="row"><?php _e("Clear Estatebud Cache", "estatebud");?></th>
            <td>
                <?php submit_button("Clear Cache", "secondary", "clear_cache", "false"); ?>
            </td>
        </tr>
        <tr style="border-top: 1px solid #eee;"><td colspan="2">&nbsp;</td></tr>
        <tr valign="top">
            <th scope="row"><?php _e("Google Maps API Key", "estatebud");?></th>
            <td>
                <input type="text" name="estatebud_gmaps_api_key" class="estatebud-api-key-input" value="<?php echo $gmaps_value; ?>" />
                <p class='description'><?php echo __("You can get an API key from <a href='https://developers.google.com/maps/documentation/javascript/get-api-key' target='_blank'>here</a>.","estatebud");?></p>
            </td>
        </tr>
		<tr><td colspan="2">&nbsp;</td></tr>
		<tr style="border-top: 1px solid #eee;"><td colspan="2">&nbsp;</td></tr>
        <tr valign="top">
            <th scope="row"><?php _e("Google reCAPTCHA", "estatebud");?></th>
            <td>
				<label for="estatebud_use_recaptcha">
					<input type="checkbox" name="estatebud_use_recaptcha" id="estatebud_use_recaptcha" <?php echo $use_recaptcha ? "checked" : ""; ?> />
					Enable reCAPTCHA (v3 supersedes v2 if both are configured)
				</label>
            </td>
        </tr>
		<tr><td colspan="2">&nbsp;</td></tr>
        <tr style="border-top: 1px solid #eee;"><td colspan="2">&nbsp;</td></tr>
        <tr valign="top">
            <th scope="row"><?php _e("reCAPTCHA v3 Site Key", "estatebud");?></th>
            <td>
                <input type="text" name="recaptcha3_sitekey_value" class="estatebud-api-key-input" value="<?php echo $recaptcha3_sitekey_value; ?>" />
            </td>
        </tr>
        <tr valign="top">
            <th scope="row"><?php _e("reCAPTCHA v3 Site Secret", "estatebud");?></th>
            <td>
                <input type="text" name="estatebud_gcaptcha3_secret" class="estatebud-api-key-input" value="<?php echo $estatebud_gcaptcha3_secret; ?>" />
                <p class='description'><?php echo __("You can get the reCAPTCHAv3 keys from <a href='https://www.google.com/recaptcha/admin' target='_blank'>here</a>.","estatebud");?></p>
            </td>
        </tr>
        <tr><td colspan="2">&nbsp;</td></tr>
        <tr style="border-top: 1px solid #eee;"><td colspan="2">&nbsp;</td></tr>
        <tr valign="top">
            <th scope="row"><?php _e("reCAPTCHA v2 Site Key", "estatebud");?></th>
            <td>
                <input type="text" name="recaptcha_sitekey_value" class="estatebud-api-key-input" value="<?php echo $recaptcha_sitekey_value; ?>" />
            </td>
        </tr>
        <tr valign="top">
            <th scope="row"><?php _e("reCAPTCHA v2 Site Secret", "estatebud");?></th>
            <td>
                <input type="text" name="estatebud_gcaptcha_secret" class="estatebud-api-key-input" value="<?php echo $estatebud_gcaptcha_secret; ?>" />
                <p class='description'><?php echo __("You can get the reCAPTCHA keys from <a href='https://www.google.com/recaptcha/admin' target='_blank'>here</a>.","estatebud");?></p>
            </td>
        </tr>
        <tr><th scope="row">&nbsp;</th><td><?php submit_button(); ?></td></tr>
    </table>
</form>