<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       http://estatebud.com
 * @since      1.0.0
 *
 * @package    Estatebud
 * @subpackage Estatebud/admin/partials
 */

if (!isset($estatebud_api)) return;

if (isset($_POST['estatebud_listing_submitted'])) {
	$estatebud_rental_availability_days = $_POST["estatebud_rental_availability_days"];
	$estatebud_show_rental_available_date = isset($_POST["estatebud_show_rental_available_date"]);
    $show_branch = isset($_POST["estatebud_show_branch"]);
    $show_agents = isset($_POST["estatebud_show_agents"]);
    $estatebud_listing_map_position = $_POST["estatebud_listing_map_position"];
    $estatebud_show_listing_map = isset($_POST["estatebud_show_listing_map"]);
    $estatebud_group_listing_markers = isset($_POST["estatebud_group_listing_markers"]);

    update_option('estatebud_rental_availability_days', $estatebud_rental_availability_days);
    update_option('estatebud_show_rental_available_date', $estatebud_show_rental_available_date);
    update_option('estatebud_show_branch', $show_branch);
    update_option('estatebud_show_agents', $show_agents);
    update_option('estatebud_show_listing_map', $estatebud_show_listing_map);
    update_option('estatebud_group_listing_markers', $estatebud_group_listing_markers);
    update_option('estatebud_listing_map_position', $estatebud_listing_map_position);
} else {
    $estatebud_rental_availability_days = get_option('estatebud_rental_availability_days', "30");
    $estatebud_show_rental_available_date = get_option('estatebud_show_rental_available_date', false);
    $show_branch = get_option('estatebud_show_branch', false);
    $show_agents = get_option('estatebud_show_agents', false);
    $estatebud_show_listing_map = get_option('estatebud_show_listing_map', false);
    $estatebud_listing_map_position = get_option('estatebud_listing_map_position', "top");
    $estatebud_group_listing_markers = get_option('estatebud_group_listing_markers', false);
}

if (isset($_POST['estatebud_listing_type'])) {
    $listing_type = sanitize_text_field($_POST["estatebud_listing_type"]);
    update_option("estatebud_listing_type", $listing_type);
} else {
    $listing_type = get_option("estatebud_listing_type","");
}

if (isset($_POST['estatebud_details_type'])) {
    $details_type = sanitize_text_field($_POST["estatebud_details_type"]);
    update_option("estatebud_details_type", $details_type);
} else {
    $details_type = get_option("estatebud_details_type","1");
}
?>
<form method="post">
    <input type="hidden" name="estatebud_listing_submitted" value="true">
    <table class="form-table">
		<tr valign="top">
            <th scope="row"><?php _e("Rental availability", "estatebud"); ?></th>
            <td>
				<select name="estatebud_rental_availability_days">
					<option value="15"<?php if($estatebud_rental_availability_days == '15') echo ' selected="selected"'; ?>><?php _e("15 days", "estatebud"); ?></option>
					<option value="30"<?php if($estatebud_rental_availability_days == '30') echo ' selected="selected"'; ?>><?php _e("30 days", "estatebud"); ?></option>
					<option value="60"<?php if($estatebud_rental_availability_days == '60') echo ' selected="selected"'; ?>><?php _e("60 days", "estatebud"); ?></option>
					<option value="90"<?php if($estatebud_rental_availability_days == '90') echo ' selected="selected"'; ?>><?php _e("90 days", "estatebud"); ?></option>
				</select>
				<p class="description">Select when rented properties should be listed as available again. The date is calculated based on the end date of the tenancy.</p>
			</td>
        </tr>
		<tr valign="top">
            <th scope="row"><?php _e("Rental available date", "estatebud"); ?></th>
            <td>
				<label for="estatebud_show_rental_available_date">
					<input type="checkbox" name="estatebud_show_rental_available_date" id="estatebud_show_rental_available_date" <?php echo $estatebud_show_rental_available_date ? "checked" : ""; ?> />
					Show date when a rented property is expected to become available.
				</label>
			</td>
        </tr>
		<tr><td colspan="2">&nbsp;</td></tr>
		<tr style="border-top: 1px solid #eee;"><td colspan="2">&nbsp;</td></tr>
        <tr valign="top">
            <th scope="row"><?php _e("Default view", "estatebud"); ?></th>
            <td class="estatebud_listing_type">
                <label><input type="radio" name="estatebud_listing_type" value="" <?php echo $listing_type == "" ? "checked" : ""; ?> /><img class='estatebud_admin_listing_type_icon svg' src='<?php echo plugin_dir_url(__FILE__);?>../assets/listing-1.svg'></label>
                <label><input type="radio" name="estatebud_listing_type" value="estatebud-listing-type-list" <?php echo $listing_type == "estatebud-listing-type-list" ? "checked" : ""; ?> /><img class='estatebud_admin_listing_type_icon svg' src='<?php echo plugin_dir_url(__FILE__);?>../assets/listing-2.svg'></label>
            </td>
        </tr>
        <tr valign="top">
            <th scope="row"><?php _e("Single listing template", "estatebud"); ?></th>
            <td class="estatebud_listing_type">
                <label><input type="radio" name="estatebud_details_type" value="1" <?php echo ($details_type == "1" || $details_type == "") ? "checked" : ""; ?> /><img class='estatebud_admin_listing_type_icon svg' src='<?php echo plugin_dir_url(__FILE__);?>../assets/details-1.svg'></label>
                <label><input type="radio" name="estatebud_details_type" value="2" <?php echo $details_type == "2" ? "checked" : ""; ?> /><img class='estatebud_admin_listing_type_icon svg' src='<?php echo plugin_dir_url(__FILE__);?>../assets/details-2.svg'></label>
                <label><input type="radio" name="estatebud_details_type" value="3" <?php echo $details_type == "3" ? "checked" : ""; ?> /><img class='estatebud_admin_listing_type_icon svg' src='<?php echo plugin_dir_url(__FILE__);?>../assets/details-3.svg'></label>
            </td>
        </tr>
		<tr valign="top">
            <th scope="row"><?php _e("Branch details", "estatebud"); ?></th>
            <td>
				<label for="estatebud_show_branch">
					<input type="checkbox" name="estatebud_show_branch" id="estatebud_show_branch" <?php echo $show_branch ? "checked" : ""; ?> />
					Show branch contact details
				</label>
			</td>
        </tr>
		<tr valign="top">
            <th scope="row"><?php _e("Agent details", "estatebud"); ?></th>
            <td>
				<label for="estatebud_show_agents">
					<input type="checkbox" name="estatebud_show_agents" id="estatebud_show_agents" <?php echo $show_agents ? "checked" : ""; ?> />
					Show agent contact details
				</label>
			</td>
        </tr>
        <tr><td colspan="2">&nbsp;</td></tr>
        <tr style="border-top: 1px solid #eee;"><td colspan="2">&nbsp;</td></tr>
        <tr valign="top">
            <th scope="row"><?php _e("Interactive map", "estatebud"); ?></th>
            <td>
				<label for="estatebud_show_listing_map">
					<input type="checkbox" name="estatebud_show_listing_map" id="estatebud_show_listing_map" <?php echo $estatebud_show_listing_map ? "checked" : ""; ?> />
					Use interactive map and standard search together
				</label>
			</td>
        </tr>
        <tr valign="top">
            <th scope="row"><?php _e("Group markers", "estatebud"); ?></th>
            <td>
				<label for="estatebud_group_listing_markers">
					<input type="checkbox" name="estatebud_group_listing_markers" id="estatebud_group_listing_markers" <?php echo $estatebud_group_listing_markers ? "checked" : ""; ?> />
					Group all properties at a distance instead of displaying individual results
				</label>
			</td>
        </tr>
        <tr valign="top">
            <th scope="row"><?php _e("Map position", "estatebud"); ?></th>
            <td>
                <label for="estatebud_show_listing_map_top">
                    <input type="radio" id="estatebud_show_listing_map_top" name="estatebud_listing_map_position" value="top" <?php echo $estatebud_listing_map_position == "top" ? "checked" : ""; ?> />
                    <?php echo __("Top", "estatebud")?>
                </label>&nbsp;
                <label for="estatebud_show_listing_map_bottom">
                    <input type="radio"  id="estatebud_show_listing_map_bottom" name="estatebud_listing_map_position" value="bottom" <?php echo $estatebud_listing_map_position == "bottom" ? "checked" : ""; ?> />
                    <?php echo __("Bottom", "estatebud")?>
                </label>
            </td>
        </tr>
        <tr><th scope="row">&nbsp;</th><td><?php submit_button(); ?></td></tr>
    </table>
</form>
