<?php /**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       http://estatebud.com
 * @since      1.0.0
 *
 * @package    Estatebud
 * @subpackage Estatebud/admin/partials
 */

if (!isset($estatebud_api)) return;


if(isset($_POST["estatebud_email_company_subject"])){
    update_option("estatebud_email_company_subject", sanitize_text_field($_POST["estatebud_email_company_subject"]));
    update_option("estatebud_email_user_subject", sanitize_text_field($_POST["estatebud_email_user_subject"]));
    update_option("estatebud_email_privacy_policy_url", sanitize_text_field($_POST["estatebud_email_privacy_policy_url"]));
    update_option("estatebud_email_sender_name", sanitize_text_field($_POST["estatebud_email_sender_name"]));
    update_option("estatebud_email_sender_address", sanitize_text_field($_POST["estatebud_email_sender_address"]));
    update_option("estatebud_email_company_recipient", sanitize_text_field($_POST["estatebud_email_company_recipient"]));
    update_option("estatebud_email_company_line", sanitize_text_field($_POST["estatebud_email_company_line"]));
    update_option("estatebud_email_footer_line", sanitize_text_field($_POST["estatebud_email_footer_line"]));
    update_option("estatebud_email_template_user", wp_kses_post($_POST["estatebud_email_template_user"]));
    update_option("estatebud_email_template_contact", wp_kses_post($_POST["estatebud_email_template_contact"]));
    update_option("estatebud_email_to_company_enabled", isset($_POST["estatebud_email_to_company_enabled"]) ? "1" : "0");

    update_option("estatebud_save_to_crm_deal", isset($_POST["estatebud_save_to_crm_deal"]) ? "1" : "0");
    update_option("estatebud_crm_pipeline_id", intval($_POST["estatebud_crm_pipeline_id"]));
    update_option("estatebud_crm_stage_id", intval($_POST["estatebud_crm_stage_id"]));

}

$crm_pipelines = $estatebud_api->get_pipelines();
$crm_pipelines_json = json_encode( $crm_pipelines, JSON_HEX_QUOT );
echo "<script>var estatebud_pipelines = JSON.parse('$crm_pipelines_json');</script>";
?>

<div class="wrap">
    <form method="post">
        <table class="form-table">
            <tbody>
                <tr><td colspan=2><h2>Property Inquiries</h2></td></tr>
                <tr>
                    <th scope="row"><?php _e("Send to CRM", "estatebud"); ?></th>
                    <td>
                        <?php $content = get_option('estatebud_save_to_crm_deal', false); ?>
		                <label for="estatebud_save_to_crm_deal">
                            <input type="checkbox" value="on" name="estatebud_save_to_crm_deal" id="estatebud_save_to_crm_deal" <?php echo $content ? "checked" : "";?>>
                            <?php echo __("Automatically send inquiries to the CRM (requires Business/Enterprise plans)", "estatebud"); ?>
                        </label>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php _e("Deal Pipeline", "estatebud"); ?></th>
                    <td>
                        <?php $pipeline_id = get_option('estatebud_crm_pipeline_id', -1); ?>
		                <div class='form-field'>
                            <select name="estatebud_crm_pipeline_id" onchange="switchSelect(this)">
                                <option value="-1" selected><?php echo __("None", "estatebud");?></option>
                                <?php foreach($crm_pipelines as $pipeline) : ?>
                                <option value='<?php echo $pipeline->id;?>'><?php echo $pipeline->name;?></option>
                                <?php endforeach;?>
                            </select>
                        </div>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php _e("Deal Stage", "estatebud"); ?></th>
                    <td>
                        <?php $stage_id = get_option('estatebud_crm_stage_id', -1); ?>
		                <div class='form-field'>
                            <select name="estatebud_crm_stage_id"></select>
                        </div>
                        <script>
                            var switchSelect = function(sel){
                                var selectedPipeline = estatebud_pipelines.filter(function(item){ return item.id == jQuery(sel).val(); })[0];
                                var stageSelect = jQuery("[name='estatebud_crm_stage_id']").first();
                                stageSelect.empty();
                                stageSelect.append("<option value='-1' selected><?php echo __('None', "estatebud");?></option>");
                                if(selectedPipeline){
                                    for(var i = 0; i < selectedPipeline.stages.length; i++)
                                    {
                                        stageSelect.append("<option value='" + selectedPipeline.stages[i].id + "'>"+selectedPipeline.stages[i].name+"</option>");
                                    }
                                }
                            }

                            jQuery(document).ready(function(){
                                var firstSelect = jQuery("[name='estatebud_crm_pipeline_id']");
                                var secondSelect = jQuery("[name='estatebud_crm_stage_id']");
                                console.log("<?php echo $pipeline_id;?>", "<?php echo $stage_id;?>");
                                firstSelect.val("<?php echo $pipeline_id;?>").trigger('change');
                                secondSelect.val("<?php echo $stage_id;?>");
                            });

                        </script>
                    </td>
                </tr>
                <tr><th colspan=2><hr></th></tr>
                <tr><td colspan=2><h2>Email Settings</h2></td></tr>
                <tr>
                    <th scope="row"><?php _e("Send emails", "estatebud"); ?></th>
                    <td>
                        <?php $content = get_option('estatebud_email_to_company_enabled', true); ?>
		                <label for="estatebud_group_listing_markers">
                            <input type='checkbox' value="on" name='estatebud_email_to_company_enabled' <?php echo ($content ? "checked" : "");?>>
                            <?php echo __("Send property inquiries on email", "estatebud"); ?>
                        </label>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php _e("Subject for Company Email", "estatebud"); ?></th>
                    <td>
                        <?php $content = sanitize_text_field(get_option('estatebud_email_company_subject')); ?>
		                <div class='form-field'>
                            <input type='text' name='estatebud_email_company_subject' value='<?php echo $content;?>'></div>
                            <p class='description'><?php echo __("This will be the subject of the email which is sent to you.", "estatebud"); ?></p>
                        </div>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php _e("Subject for User Email", "estatebud"); ?></th>
                    <td>
                        <?php $content = sanitize_text_field(get_option('estatebud_email_user_subject')); ?>
		                <div class='form-field'>
                            <input type='text' name='estatebud_email_user_subject' value='<?php echo $content;?>'></div>
                            <p class='description'><?php echo __("This will be the subject of the email which is sent to the contact requester.", "estatebud"); ?></p>
                        </div>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php _e("Privacy Policy URL", "estatebud"); ?></th>
                    <td>
                        <?php $pp_url = get_option('estatebud_email_privacy_policy_url', false);
                        if ($pp_url == false) {
                            $pp_url = "";
                            update_option('estatebud_email_privacy_policy_url', $pp_url);
                        }
                        $content = sanitize_text_field($pp_url); ?>
		                <div class='form-field'>
                            <input type='text' name='estatebud_email_privacy_policy_url' value='<?php echo $content;?>'></div>
                            <p class='description'><?php echo __("Privacy Policy document link which will be visible below the contact form if set.", "estatebud"); ?></p>
                        </div>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php _e("Sender E-mail Name", "estatebud"); ?></th>
                    <td>
                        <?php $sender_name = get_option('estatebud_email_sender_name', false);
                        if ($sender_name == false) {
                            $sender_name = get_bloginfo("blogname");
                            update_option('estatebud_email_sender_name', $sender_name);
                        }
                        $content = sanitize_text_field($sender_name); ?>
		                <div class='form-field'>
                            <input type='text' name='estatebud_email_sender_name' value='<?php echo $content;?>'></div>
                            <p class='description'><?php echo __("Visible Sender Name of the e-mail", "estatebud"); ?></p>
                        </div>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php _e("Sender E-mail Address", "estatebud"); ?></th>
                    <td>
                        <?php $sender_address = get_option('estatebud_email_sender_address', false);
                        if ($sender_address == false) {
                            $sitename = strtolower($_SERVER["SERVER_NAME"]);
                            if (substr($sitename, 0, 4) == "www.") {
                                $sitename = substr($sitename, 4);
                            }
                            $sender_address = "wordpress@$sitename";
                            update_option('estatebud_email_sender_address', $sender_address);
                        }
                        $content = sanitize_text_field($sender_address); ?>
		                <div class='form-field'>
                            <input type='text' name='estatebud_email_sender_address' value='<?php echo $content;?>'></div>
                            <p class='description'><?php echo __("Visible Sender Address of the e-mail", "estatebud"); ?></p>
                        </div>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php _e("Recipient Address(es) for Company Email", "estatebud"); ?></th>
                    <td>
                        <?php $recipient = get_option('estatebud_email_company_recipient', false);
                        if ($recipient == false) {
                            $recipient = get_bloginfo("admin_email");
                            update_option('estatebud_email_company_recipient', $recipient);
                        }
                        $content = sanitize_text_field($recipient); ?>
		                <div class='form-field'>
                            <input type='text' name='estatebud_email_company_recipient' value='<?php echo $content;?>'></div>
                            <p class='description'><?php echo __("Seperate e-mail addresses with <code>;</code>", "estatebud"); ?></p>
                        </div>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php _e("Company Info Text", "estatebud"); ?></th>
                    <td>
                        <?php $content = sanitize_text_field(get_option('estatebud_email_company_line')); ?>
		                <div class='form-field'>
                            <input type='text' name='estatebud_email_company_line' value='<?php echo $content;?>'></div>
                            <p class='description'><?php echo __("This will be on the footer of the email template where <code>%company_info%</code> placeholder exists.", "estatebud"); ?></p>
                        </div>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php _e("Footer Line Text", "estatebud"); ?></th>
                    <td>
                        <?php $content = sanitize_text_field(get_option('estatebud_email_footer_line')); ?>
		                <div class='form-field'>
                            <input type='text' name='estatebud_email_footer_line' value='<?php echo $content;?>'></div>
                            <p class='description'><?php echo __("This will be on the footer of the email template where <code>%footer_text%</code> placeholder exists.", "estatebud"); ?></p>
                        </div>
                    </td>
                </tr>
                <tr><th colspan=2><hr></th></tr>
                <tr><td colspan=2>
                <h2>Email Templates</h2>
                    <?php _e('You can customize the e-mails sent both to the requester and the company when someone requests more information about a property via the contact form on the property page or from the widget.', "estatebud");?>
                    <br><br><br>
                    <div class="estatebud-info">
                        <b><?php _e('Available placeholders:', "estatebud");?></b>
                        <br><br>
                        <table>
                            <tr>
                                <td style='width:200px'><code>%name%</code></td><td><?php _e('User\'s name.', "estatebud");?></td>
                                <td><code>%reference_id%</code></td><td><?php _e('The property ID which user enquired about.', "estatebud");?></td>
                            </tr>
                            <tr>
                                <td><code>%email%</code></td><td><?php _e('The email of the enquiring user.', "estatebud");?></td>
                                <td><code>%website_name%</code></td><td><?php _e('The website name which the form has been submitted.', "estatebud");?></td>
                            </tr>
                            <tr>
                                <td><code>%website_url%</code></td><td><?php _e('The website URL which the form has been submitted.', "estatebud");?></td>
                                <td><code>%phone%</code></td><td><?php _e('The user\'s phone number if entered.', "estatebud");?></td>
                            </tr>
                            <tr>
                                <td><code>%message%</code></td><td><?php _e('The user\'s message.', "estatebud");?></td>
                                <td><code>%timestamp%</code></td><td><?php _e('The date/time when the user submitted the form.', "estatebud");?></td>
                            </tr>
                            <tr>
                                <td><code>%company_info%</code></td><td><?php _e('The company info input you enter on this form. Shown on footer.', "estatebud");?></td>
                                <td><code>%footer_text%</code></td><td><?php _e('The footer input you enter on this form. Shown on footer.', "estatebud");?></td>
                            </tr>
                        </table>
                        <br>
                    </div>
                    <br>
                </td></tr>
                <tr>
                    <th scope="row"><?php _e("E-mail sent to the user", "estatebud"); ?></th>
                    <td>
                        <div class='form-field'>
                        <?php $content = get_option('estatebud_email_template_user');
		                wp_editor($content, 'estatebud_email_template_user');?>
                        </div>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php _e("E-mail sent to the company", "estatebud"); ?></th>
                    <td>
		                <div class='form-field'>
                        <?php $content = get_option('estatebud_email_template_contact');
                        wp_editor($content, 'estatebud_email_template_contact');?>
                        </div>
                    </td>
                </tr>
            </tbody>
        </table>
        <?php submit_button(); ?>
    </form>
</div>