<?php
/**
 * Define the internationalization functionality.
 *
 * Loads and defines the internationalization files for this plugin
 * so that it is ready for translation.
 *
 * @since      1.0.0
 * @package    Estatebud
 * @subpackage Estatebud/includes
 * @author     Estatebud
 */
class Estatebud_i18n
{

    public $translations = [];

    public $loaded = [];

    /**
	 * Load the plugin text domain for translation.
	 *
	 * @since    1.0.0
	 */
    public function load_plugin_textdomain()
    {
        if (isset($_GET["lang"])) {
            $locale = $_GET["lang"];
            add_filter('determine_locale', function()use($locale){ return $locale; });
        }

        load_plugin_textdomain(
            'estatebud',
            false,
            dirname(dirname(plugin_basename(__FILE__))) . '/languages/'
        );

        $this->loadTranslation("en");
        $this->loadTranslation(get_locale());
    }

    public function loadTranslation($locale){
        $locale = explode("_", $locale)[0];
        $path = plugin_dir_path(__FILE__) . "../languages/json/estatebud-$locale.json";
		
        if(file_exists($path)){
            if(in_array($locale, $this->loaded) == false){
                $translations = json_decode(file_get_contents($path), true);
				$translationsArray = array();
				
				foreach($translations AS $translation) {
					if(isset($translation['text']['other'])) {
						$translationsArray[$translation['key']] = array("one" => $translation['text']['one'], "other" => $translation['text']['other']);
					} else {
						$translationsArray[$translation['key']] = array("one" => $translation['text']);
					}
				}
				
                $this->translations = array_merge($this->translations, $translationsArray);
                $this->loaded[] = $locale;
				
				unset($translations);
				unset($translationsArray);
            }
        }
    }

    public function translate($key, $count)
    {
		if($count == 1) {
            return $this->translations[$key]['one'] ?? __($key, "estatebud");
        } else {
            return $this->translations[$key]['other'] ?? __($key, "estatebud");
        }
    }
}

function estatebud__($key, $count = 1)
{
    global $estatebud_plugin;
    $translator = $estatebud_plugin->get_translator();
    return $translator->translate($key, $count);
}

function estatebud_e($key, $count = 1)
{
    global $estatebud_plugin;
    $translator = $estatebud_plugin->get_translator();
    echo $translator->translate($key, $count);
}