<?php

class Estatebud_Search_Widget extends WP_Widget
{
    private $version = "3.0.0";

    function __construct()
    {
        parent::__construct(
            'estatebud-search-widget',  // Base ID
            __("Estatebud Search Widget", "estatebud")   // Name
        );
        add_action('widgets_init', function () {
            register_widget('Estatebud_Search_Widget');
        });

        add_action('wp_enqueue_scripts', array($this, 'scripts'));
        if(!has_action("estatebud_render_searchbox")) {
            add_action('estatebud_render_searchbox', array($this, 'render_searchbox'), 2, 3);
        }
        if(!has_action("estatebud_render_searchbox_contents")) {
            add_action('estatebud_render_searchbox_contents', array($this, 'render_searchbox_contents'), 2, 3);
        }
    }

    public $args = array(
        'before_title' => '<h4 class="widgettitle">',
        'after_title' => '</h4>',
        'before_widget' => '<div class="widget-wrap">',
        'after_widget' => '</div></div>'
    );

    public function scripts(){
        if(wp_script_is("estatebud-select") == false){
            wp_enqueue_style("estatebud-select", plugin_dir_url(__FILE__) . '../public/css/sumoselect.css', array(), $this->version, 'all');
            wp_enqueue_style("estatebud-override", plugin_dir_url(__FILE__) . '../public/css/estatebud-sumoselect.css', array(), $this->version, 'all');
            wp_enqueue_script("estatebud-select", plugin_dir_url(__FILE__) . '../public/js/sumoselect.full.min.js', array('jquery'), $this->version, false);
        }
    }

    public function widget($args, $instance)
    {

        echo $args['before_widget'];

        if(isset($instance["searchbox"])){
            $this->render_searchbox($instance["searchbox"], $instance, false);
        }

        echo $args['after_widget'];
    }

    public function render_searchbox_contents($html, $data, $for_listing, $item = null)
    {
        $estatebud_api = new EstatebudAPI(get_option("estatebud_api_key", null), isset($_GET["lang"]) ? $_GET["lang"] : get_locale());

        if($estatebud_api->auth_info === null){
            echo "<b>Estatebud Error: </b>Your API key seems to be missing or invalid. Please update your API key and re-check.";
            return;
        }

        $request = $data;

        $document = new DOMDocument();
        $document->loadHTML(mb_convert_encoding($html, 'HTML-ENTITIES', 'UTF-8'), LIBXML_HTML_NOIMPLIED | LIBXML_HTML_NODEFDTD);

        $inputs = scandir(rtrim(dirname(__FILE__), "/") . "/../public/partials/inputs");

        foreach($inputs as $input)
        {
            if(strpos($input, ".php") > 0){
                require(rtrim(dirname(__FILE__), "/") . "/../public/partials/inputs/$input");
            }
        }

        $widget_template = $document->saveHTML();

        if($for_listing == false && $item != null){
            if($item["item_type"] == "post"){
                $url = site_url().get_permalink($item["redirect_post"]);
            }else{
                $url = site_url()."/".get_page_uri($item["redirect_page"]);
            }

            echo "<form method='GET' action='".$url."'><input type='hidden' name='from' value='searchbox'>".$widget_template."</form>";

            ?>
            <script>
            (function ($) {
                $(document).ready(function () {
                    jQuery(".widget_estatebud-search-widget").each(function () {
                        $(".estatebud-filter-form-more", this).replaceWith($(".estatebud-filter-form-more").html());
                        window.estatebudStylizeFilterForm($(this));
                    }).addClass("estatebud-filter-form");
                });
            })(jQuery);
            </script>

        <?php
        }else{
            echo $widget_template;
        }
    }

    public function render_searchbox($key, $data, $for_listing)
    {
        $items = get_option("estatebud_widget_settings", false);

        if($items && $items[$key]){
            $item = $items[$key];
            $widget_template = stripslashes($item["template"]);
            $widget_template = preg_replace_callback('/\$\{([^}]+)\}\$/m', function($match) {
                $parts = explode(",", $match[1]);
                if(count($parts) == 1) {
                    return estatebud__($parts[0]);
                }
                return estatebud__($parts[0], $parts[1]);
            }, $widget_template);

            $widget_template = mb_convert_encoding($widget_template, "HTML-ENTITIES", "UTF-8");

            $this->render_searchbox_contents($widget_template, $data, $for_listing, $item);
        }
    }

    public function form($instance)
    {
        $searchbox = !empty($instance['searchbox']) ? $instance['searchbox'] : esc_html__('', 'estatebud');
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('searchbox')); ?>"><?php esc_attr_e('Search box:', 'estatebud'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('searchbox')); ?>" name="<?php echo esc_attr($this->get_field_name('searchbox')); ?>" >
                <?php
                $items = get_option("estatebud_widget_settings", false);
                if($items){
                    foreach($items as $key => $item){
                        echo "<option value='" . $key . "'" . (($searchbox == $key) ? " selected" : "") . ">" . $item["label"] . "</option>";
                    }
                } ?>
            </select>
        </p>
        <?php
    }

    public function update($new_instance, $old_instance)
    {
        $instance = array();
        $instance['searchbox'] = (!empty($new_instance['searchbox'])) ? strip_tags($new_instance['searchbox']) : '';
        return $instance;
    }
}
$estatebud_search_widget = new Estatebud_Search_Widget();