<?php

class Estatebud_Slider_Widget extends WP_Widget
{

    function __construct()
    {
        parent::__construct(
            'estatebud-slider-widget',  // Base ID
            __("Estatebud Property Slider Widget", "estatebud")   // Name
        );
        add_action('widgets_init', function () {
            register_widget('Estatebud_Slider_Widget');
        });
    }

    public $args = array(
        'before_title' => '<h4 class="widgettitle">',
        'after_title' => '</h4>',
        'before_widget' => '<div class="widget-wrap">',
        'after_widget' => '</div></div>'
    );

    public function widget($args, $instance)
    {
        wp_enqueue_script("estatebud-slider", plugin_dir_url(__FILE__) . '../public/js/slick.min.js', array('jquery'), null, false);
        wp_enqueue_style("estatebud_slider", plugin_dir_url(__FILE__) . '../public/css/slick.css');

        echo $args['before_widget'];
        if (!empty($instance['title'])) {
            echo $args['before_title'] . apply_filters('widget_title', $instance['title']) . $args['after_title'];
        }
        $uniqueID = uniqid();
        $shortcode = "[estatebud_" . $instance["shortcode"] . " is_widget='true' is_slider='". $uniqueID .
        "' autoplay=" . $instance["autoplay"] . " limit='" . $instance["limit"] .
        "' autoplayDuration='" . $instance["autoplayDuration"] . "' visibleCount='". $instance["visibleCount"] .
        "' scrollCount='". $instance["scrollCount"] ."' layout='".$instance["layout"]."' slider_template='".$instance["slider_template"]."']";
        echo do_shortcode($shortcode);
        echo $args['after_widget'];
    }

    public function form($instance)
    {
        $title = !empty($instance['title']) ? $instance['title'] : esc_html__('', 'estatebud');
        $limit = !empty($instance['limit']) ? intval($instance['limit']) : 1;
        $visibleCount = !empty($instance['visibleCount']) ? intval($instance['visibleCount']) : 3;
        $scrollCount = !empty($instance['scrollCount']) ? intval($instance['scrollCount']) : 3;
        $autoplay = !empty($instance['autoplay']) ? ($instance['autoplay'] ? true : false) : false;
        $infinite = !empty($instance['infinite']) ? ($instance['infinite'] ? true : false) : false;
        $autoplayDuration = !empty($instance['autoplayDuration']) ? intval($instance['autoplayDuration']) : 2000;
        $shortcode = !empty($instance['shortcode']) ? $instance['shortcode'] : esc_html__('', 'estatebud');
        $slider_template = !empty($instance['slider_template']) ? $instance['slider_template'] : "slider-multi";
        $layout = !empty($instance['layout'] ) ? $instance['layout'] : "vertical";
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_attr_e('Title:', 'estatebud'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('limit')); ?>"><?php esc_attr_e('Property Count:', 'estatebud'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('limit')); ?>" name="<?php echo esc_attr($this->get_field_name('limit')); ?>" >
                <?php for ($i = 1; $i < 50; $i++) {
                    echo "<option value='$i'" . (($limit == $i) ? " selected" : "") . ">$i</option>";
                } ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('visibleCount')); ?>"><?php esc_attr_e('Visible Properties Count:', 'estatebud'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('visibleCount')); ?>" name="<?php echo esc_attr($this->get_field_name('visibleCount')); ?>" >
                <?php for ($i = 1; $i < 50; $i++) {
                    echo "<option value='$i'" . (($visibleCount == $i) ? " selected" : "") . ">$i</option>";
                } ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('scrollCount')); ?>"><?php esc_attr_e('Scrolling Properties Count:', 'estatebud'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('scrollCount')); ?>" name="<?php echo esc_attr($this->get_field_name('scrollCount')); ?>" >
                <?php for ($i = 1; $i < 50; $i++) {
                    echo "<option value='$i'" . (($scrollCount == $i) ? " selected" : "") . ">$i</option>";
                } ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('infinite')); ?>"><?php esc_attr_e('Infinite?', 'estatebud'); ?></label>
            <input type="checkbox" id="<?php echo esc_attr($this->get_field_id('infinite')); ?>"
                name="<?php echo esc_attr($this->get_field_name('infinite')); ?>" <?php echo $infinite ? "checked='checked'" : ""?>>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('autoplay')); ?>"><?php esc_attr_e('Auto Play Slider?', 'estatebud'); ?></label>
            <input type="checkbox" id="<?php echo esc_attr($this->get_field_id('autoplay')); ?>"
                name="<?php echo esc_attr($this->get_field_name('autoplay')); ?>" <?php echo $autoplay ? "checked='checked'" : ""?>>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('autoplayDuration')); ?>"><?php esc_attr_e('Auto Play Duration:', 'estatebud'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('autoplayDuration')); ?>" name="<?php echo esc_attr($this->get_field_name('autoplayDuration')); ?>"
                type="number" min="100" max="15000" value="<?php echo esc_attr($autoplayDuration); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('shortcode')); ?>"><?php esc_attr_e('Shortcode:', 'estatebud'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('shortcode')); ?>" name="<?php echo esc_attr($this->get_field_name('shortcode')); ?>" >
                <?php
                $shortcodes = get_option("estatebud_shortcode_settings", []);
                foreach (array_keys($shortcodes) as $shortcode_tag) {
                    echo "<option value='".esc_attr($shortcode_tag)."'" . (($shortcode_tag == $shortcode) ? " selected" : "") . ">[estatebud_$shortcode_tag]</option>";
                } ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('layout')); ?>"><?php esc_attr_e('Layout:', 'estatebud'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('layout')); ?>" name="<?php echo esc_attr($this->get_field_name('layout')); ?>" >
                <?php
                foreach (["horizontal","vertical"] as $xlayout) {
                    echo "<option value='".esc_attr($xlayout)."'" . (($layout == $xlayout) ? " selected" : "") . ">". ucfirst($xlayout) . "</option>";
                } ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('slider_template')); ?>"><?php esc_attr_e('Slider Template:', 'estatebud'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('slider_template')); ?>" name="<?php echo esc_attr($this->get_field_name('slider_template')); ?>" >
                <?php
                if(!function_exists("unslug")){
                    function unslug($str){
                        return implode(" ", array_map(function($word){ return ucfirst($word); }, explode("-", $str)));
                    }
                }

                chdir(plugin_dir_path(__FILE__));

                $templates = array_map(function($str){
                    return preg_replace("/slider\/(.+).css.php/","$1", $str);
                }, glob("slider/*.css.php"));

                foreach ($templates as $xtemplate) {
                    echo "<option value='" . esc_attr($xtemplate) . "'" . (($slider_template == $xtemplate) ? " selected" : "") . ">". unslug($xtemplate) . "</option>";
                } ?>
            </select>
        </p>
        <?php
    }

    public function update($new_instance, $old_instance)
    {
        $instance = array();
        $instance['title'] = (!empty($new_instance['title'])) ? strip_tags($new_instance['title']) : '';
        $instance['limit'] = (!empty($new_instance['limit'])) ? intval($new_instance['limit']) : 0;
        $instance['visibleCount'] = (!empty($new_instance['visibleCount'])) ? intval($new_instance['visibleCount']) : 3;
        $instance['scrollCount'] = (!empty($new_instance['scrollCount'])) ? intval($new_instance['scrollCount']) : 3;
        $instance['infinite'] = (!empty($new_instance['infinite'])) ? ($new_instance['infinite'] ? true : false) : false;
        $instance['autoplay'] = (!empty($new_instance['autoplay'])) ? ($new_instance['autoplay'] ? true : false) : false;
        $instance['autoplayDuration'] = (!empty($new_instance['autoplayDuration'])) ? intval($new_instance['autoplayDuration']) : 2000;
        $instance['slider_template'] = !empty($new_instance['slider_template']) ? $new_instance['slider_template'] : "slider-multi";
        $instance['layout'] = (!empty($new_instance['layout']) && in_array($new_instance["layout"], ["vertical", "horizontal"])) ? $new_instance['layout'] : 'vertical';
        $instance['shortcode'] = (!empty($new_instance['shortcode'])) ? sanitize_text_field($new_instance['shortcode']) : 0;
        return $instance;
    }

}
$estatebud_slider_widget = new Estatebud_Slider_Widget();