var estatebud_map;
var estatebud_infowindow = null;
var estatebud_markerClusterer = null;
var estatebud_circles = {};
var estatebud_markers = [];

var estatebud_infowindow_ajax = null;
var estatebud_bounds_timer;
var estatebud_mapBounds = null;

var estatebud_expandBounds = false;
var estatebud_skipMarkerDraw = false;
var estatebud_skipRefresh = false;
var estatebud_autoFilter = true;
var estatebud_map_loaded = false;

var estatebud_zoomLimit = 15;
var estatebud_clickCircleZoom = 12;
var estatebud_circleScaleMin = 4;
var estatebud_circleScaleMax = 8;

var estatebud_pluginPath = estatebud.plugin_url + "/assets/";

var estatebud_markerClustererOptions = {
    averageCenter: true,
    calculator: function (markers) {
        var styleIndex = 1;
        switch (true) {
            case (markers.length < 100):
                styleIndex = 1;
                break;
            case (markers.length < 200):
                styleIndex = 2;
                break;
            case (markers.length < 400):
                styleIndex = 3;
                break;
            case (markers.length < 600):
                styleIndex = 4;
                break;
            default:
                styleIndex = 5;
        }

        return {
            index: styleIndex,
            text: markers.length,
            title: 'Click to zoom and show ' + markers.length + ' locations'
        }
    },
    gridSize: 100,
    zoomOnClick: true,
    maxZoom: estatebud_zoomLimit+2,
    styles: [{
        url: estatebud_pluginPath + "map-cluster1.svg?" + estatebud.version,
        width: 45,
        height: 45,
        textColor: '#fff',
        textSize: 14,
		anchorText: [14, 0]
    }, {
        url: estatebud_pluginPath + "map-cluster2.svg?" + estatebud.version,
        width: 50,
        height: 50,
        textColor: '#fff',
        textSize: 14,
		anchorText: [17, 0]
    }, {
        url: estatebud_pluginPath + "map-cluster3.svg?" + estatebud.version,
        width: 55,
        height: 55,
        textColor: '#fff',
        textSize: 16,
		anchorText: [18, 0]
    }, {
        url: estatebud_pluginPath + "map-cluster4.svg?" + estatebud.version,
        width: 60,
        height: 60,
        textColor: '#fff',
        textSize: 17,
		anchorText: [20, 0]
    }, {
        url: estatebud_pluginPath + "map-cluster5.svg?" + estatebud.version,
        width: 65,
        height: 65,
        textColor: '#fff',
        textSize: 18,
		anchorText: [22, 0]
    }]
};

function estatebud_createMap() {
    jQuery(document).ready(function () {
        var lat = parseFloat(jQuery("input[name='lat']").val()),
            lng = parseFloat(jQuery("input[name='lng']").val()),
            zoom_level = parseInt(jQuery("input[name='zoom_level']").val());

        if(!lat) lat = 33.1985875;
        if(!lng) lng = 24.4839638;
        if(!zoom_level) zoom_level = 11;

        if (window.location.search === "") {
            lat = 33.1985875; lng = 24.4839638; zoom_level = 3;
            estatebud_expandBounds = true;
        }
		
        var mapProp = {
            center: new google.maps.LatLng(lat, lng),
            zoom: zoom_level,
            gestureHandling: 'greedy',
            disableDefaultUI: true,
            zoomControl: true,
            fullscreenControl: false,
            mapTypeControl: true,
            streetViewControl: true,
            styles: [
                {
                    "featureType": "poi.business",
                    "stylers": [
                        {
                            "visibility": "off"
                        }
                    ]
                }
            ],
            mapTypeControlOptions: {
                position: google.maps.ControlPosition.LEFT_BOTTOM
            }
        };

        estatebud_map = new google.maps.Map(document.getElementById("estatebud-google-map"), mapProp);

        if(estatebud.is_listing == false){
            var autocomplete = new google.maps.places.Autocomplete(document.getElementById("estatebud-location-search"));
            autocomplete.bindTo('bounds', estatebud_map);

            autocomplete.addListener('place_changed', function () {
                var place = autocomplete.getPlace();
                if (place == "" || !place.geometry) return;

                // If the place has a geometry, then present it on a map.
                if (place.geometry.viewport) {
                    estatebud_map.fitBounds(place.geometry.viewport);
                } else {
                    estatebud_map.setCenter(place.geometry.location);
                    estatebud_map.setZoom(16);
                }
            });
        } else {
			estatebud_map.setOptions({'scrollwheel': false});
		}

        google.maps.InfoWindow.prototype.open = function () {
            return this; //prevent InfoWindow to appear
        }

        google.maps.InfoWindow.prototype.setContent = function (content) { };

        if(estatebud.is_listing == false){
            google.maps.event.addListener(estatebud_map, 'bounds_changed', function () {
                if (estatebud_skipRefresh == false && estatebud_map_loaded == true) {
                    clearTimeout(estatebud_bounds_timer);
                    estatebud_bounds_timer = setTimeout(function () {
                        estatebud_load_map_properties();
                    }, 200);
                }
                estatebud_skipRefresh = false;
            });
        }else{
            estatebud_load_map_properties();
        }

        google.maps.event.addListener(estatebud_map, 'zoom_changed', function () {
            estatebud_resizeCircles();
        });

        google.maps.event.addListenerOnce(estatebud_map, 'idle', function () {
            estatebud_map_loaded = true;
            google.maps.event.trigger(estatebud_map, "bounds_changed");
        });

        google.maps.event.addListener(estatebud_map, "click", function () {
            if (estatebud_infowindow) {
                estatebud_unslick();
            }
            jQuery(".estatebud-shortcode-filters").removeClass("estatebud-show");
        });

        // run the bounds changed event
        estatebud_skipRefresh = false;
    });
}

function estatebud_load_map_properties() {
    var bounds = estatebud_map.getBounds();
    var center = estatebud_map.getCenter();
    if (bounds && center) {
        var ne = bounds.getNorthEast();
        var radius = google.maps.geometry.spherical.computeDistanceBetween(center, ne) / 1000; // convert to km's
    }

    jQuery("input[name='lat']").val(center.lat());
    jQuery("input[name='lng']").val(center.lng());
    jQuery("input[name='radius']").val(radius);
    jQuery("input[name='offset']").val(0);
    jQuery("input[name='zoom_level']").val(estatebud_map.getZoom());

    estatebud_refresh_property_list_outside();
}

function estatebud_unslick() {
    if (estatebud_infowindow) {
        if (estatebud_infowindow.find(".estatebud-infowindow-slider").hasOwnProperty("unslick")) {
            estatebud_infowindow.find(".estatebud-infowindow-slider").slick("destroy");
            estatebud_infowindow.removeClass("estatebud-infowindow-width");
        } else {
            estatebud_infowindow.html("");
        }
    }
}

function estatebud_processData(data) {

    if (estatebud_skipMarkerDraw) {
        estatebud_skipMarkerDraw = false;
        return;
    }

    if (estatebud_expandBounds == true) {
        estatebud_mapBounds = new google.maps.LatLngBounds();
    }
    estatebud_prepareForDeletion();
    if (estatebud.groupMarkers || estatebud_map.getZoom() > estatebud_zoomLimit) {
        for (var i in data) {
            var property = data[i];
            if (property.hasOwnProperty("location_lat") && property.hasOwnProperty("location_lng") && property.location_lat !== "" && property.location_lng !== "") {
                var location = new google.maps.LatLng(parseFloat(property.location_lat), parseFloat(property.location_lng));
				estatebud_addMarker(location, property);
                if (estatebud_mapBounds){
                    estatebud_skipRefresh = true;
                    estatebud_mapBounds.extend(location);
                }
            }
        }
        estatebud_clearExtraMarkers();
        estatebud_clearCircles();
        if (estatebud.groupMarkers) {
            if (estatebud_markerClusterer == null) {
                estatebud_markerClusterer = new MarkerClusterer(estatebud_map, estatebud_markers, estatebud_markerClustererOptions);
            } else {
                estatebud_markerClusterer.clearMarkers();
                estatebud_markerClusterer.addMarkers(estatebud_markers, false);
            }
        }
    } else {
        if (estatebud_infowindow) {
            estatebud_unslick();
        }
        estatebud_clearExtraMarkers();
        estatebud_clearCircles();
        estatebud_drawCircles(data);
    }

    if (estatebud_expandBounds == true) {
        estatebud_skipRefresh = true;
        estatebud_map.fitBounds(estatebud_mapBounds);
        estatebud_mapBounds = null;
        estatebud_expandBounds = false;
    }
}

function estatebud_drawCircles(data) {
    var zoom_level = estatebud_map.getZoom();
    var circle_calc = estatebud_circleCalcSize();

    for (var i in data) {
        if (data[i].hasOwnProperty("location_lat") && data[i].hasOwnProperty("location_lng") && data[i].location_lat !== "" && data[i].location_lng !== "") {
            if (estatebud_circles.hasOwnProperty(data[i].id) == false) {
                var location = new google.maps.LatLng(parseFloat(data[i].location_lat), parseFloat(data[i].location_lng));
				var circle = {
					path: google.maps.SymbolPath.CIRCLE,
					fillOpacity: 1,
					fillColor: '#' + estatebud_getIconColor(data[i].type),
					strokeOpacity: 1,
					strokeColor: "#FFFFFF",
					strokeWeight: circle_calc.stroke_weight,
					scale: circle_calc.scale
				};

				var marker = new google.maps.Marker({
					icon: circle,
					position: location,
					data: estatebud.is_listing ? data[i] : null,
					clickable: zoom_level > estatebud_clickCircleZoom,
					property_id: data[i].id,
					type: "circle",
					map: estatebud_map
				});

                marker.addListener('click', estatebud_markerClick);

                estatebud_circles[data[i].id] = marker;
                if (estatebud_mapBounds) estatebud_mapBounds.extend(location);
            } else {
                if (estatebud_circles[data[i].id].getMap() === null) {
                    estatebud_circles[data[i].id].setMap(estatebud_map);
                }
                estatebud_circles[data[i].id].set('clickable', zoom_level > estatebud_clickCircleZoom);
                estatebud_circles[data[i].id]['icon']['scale'] = circle_calc.scale;
                estatebud_circles[data[i].id]['icon']['strokeWeight'] = circle_calc.stroke_weight;
                if (estatebud_mapBounds) estatebud_mapBounds.extend(estatebud_circles[data[i].id].center);
            }
        }
    }
}

function estatebud_circleCalcSize() {
	var zoom_level = estatebud_map.getZoom();
	var scale = Math.round(Math.pow(2,zoom_level)/1000);
	var stroke_weight = 2;

	if(scale < estatebud_circleScaleMin) {
		scale = estatebud_circleScaleMin;
	} else if(scale > estatebud_circleScaleMax) {
		scale = estatebud_circleScaleMax;
	}

	if(scale < estatebud_circleScaleMin) {
		stroke_weight = 1;
	}

	return {
		scale: scale,
		stroke_weight: stroke_weight
	}
}

function estatebud_resizeCircles() {
    if (estatebud.groupMarkers == false) {
        var zoom_level = estatebud_map.getZoom();
        var circle_calc = estatebud_circleCalcSize();

        if(estatebud.is_listing)
        {
			if(zoom_level > estatebud_zoomLimit)
            {
                // convert circles to markers
                estatebud_clearCircles();
                for (var i in estatebud_circles) {
                    estatebud_addMarker(estatebud_circles[i].getPosition(), estatebud_circles[i].data);
                }
            } else {
                // convert markers to circles
                estatebud_markers.map(marker => marker.delete = true);
                estatebud_clearExtraMarkers();
                for (var i in estatebud_circles) {
                    estatebud_circles[i].setMap(estatebud_map);
                    estatebud_circles[i]['icon']['scale'] = circle_calc.scale;
                    estatebud_circles[i]['icon']['strokeWeight'] = circle_calc.stroke_weight;
                    estatebud_circles[i].set('clickable', zoom_level > estatebud_clickCircleZoom);
                }
            }
        }else{
            for (var i in estatebud_circles) {
                if (estatebud_circles[i].getMap() !== null) {
                    estatebud_circles[i]['icon']['scale'] = circle_calc.scale;
                    estatebud_circles[i]['icon']['strokeWeight'] = circle_calc.stroke_weight;
                    estatebud_circles[i].set('clickable', zoom_level > estatebud_clickCircleZoom);
                }
            }
        }
    }
}

function estatebud_clearCircles() {
    for (var i in estatebud_circles) {
        estatebud_circles[i].setMap(null);
    }
}

function estatebud_addMarker(location, data) {
    var existing = estatebud_markers.filter(function (marker) {
        return marker.property_id == data.id;
    });
    if (existing.length == 0) {
		var markerSettings = estatebud_getMarkerLabel(data.type, location);
		markerSettings.position = location;
		markerSettings.icon = estatebud_getMarkerIcon(data.type);
		markerSettings.delete = false;
		markerSettings.property_id = data.id;
		markerSettings.type = "marker";
		var marker = new MarkerWithLabel(markerSettings);
        marker.infowindow = data.infowindow;
        marker.addListener('click', estatebud_markerClick);
        estatebud_markers.push(marker);
        return marker;
    } else {
        existing[0].delete = false;
        return existing[0];
    }
}

function estatebud_markerClick() {
    var marker = this;

    if (estatebud_infowindow == null) {
        estatebud_infowindow = jQuery("#estatebud-infowindow");
        estatebud_infowindow.off("destroy").on("destroy", function () {
            estatebud_infowindow.html("");
        });
        // On before slide change
        estatebud_infowindow.off("beforeChange").on('beforeChange', function (event, slick, currentSlide, nextSlide) {
            estatebud_infowindow.find(".estatebud-infowindow-current").text(nextSlide + 1);
            estatebud_infowindow.find(".estatebud-infowindow-total").text(slick.slideCount);
        });

        estatebud_infowindow.off('init').on('init', function (event, slick) {
            estatebud_infowindow.find(".estatebud-infowindow-current").text(1);
            estatebud_infowindow.find(".estatebud-infowindow-total").text(slick.slideCount);
        });

        estatebud_infowindow.off("click").on("click", ".estatebud-left-arrow", function () {
            estatebud_infowindow.find(".estatebud-infowindow-slider").slick("slickPrev");
        }).on("click", ".estatebud-right-arrow", function () {
            estatebud_infowindow.find(".estatebud-infowindow-slider").slick("slickNext");
        });

    } else {
        estatebud_unslick();
    }
    if (estatebud_infowindow_ajax) estatebud_infowindow_ajax.abort();
    estatebud_infowindow
        .removeClass("estatebud-infowindow-width")
        .html('<div class="estatebud-loader"><i class="fas fa-circle-notch"></i></div>');

    var location_markers = [];
    if (marker.type == "marker") {
        // find all markers on that location
        location_markers = estatebud_markers.filter(function (m) {
            return m.getPosition().equals(marker.getPosition());
        });
    } else if (marker.type == "circle") {
        for(var i in estatebud_circles){
            if(estatebud_circles[i].getPosition().equals(marker.getPosition())){
                location_markers.push({property_id: estatebud_circles[i].property_id});
            }
        }
    }

    estatebud_infowindow_ajax = jQuery.ajax({
        url: estatebud.ajaxurl,
        method: "GET",
        cache: true,
        data: {
            "id": location_markers.map(function (m) { return m.property_id; }).join(","),
            "action": "estatebud_get_infowindow",
            "security": estatebud_maps.nonce,
            "lang": estatebud.lang
        },
        success: function (data) {
            estatebud_infowindow.html(data);
            if (estatebud_infowindow.find(".estatebud-map-marker").length > 1) {
                estatebud_infowindow.addClass("estatebud-infowindow-width");
                estatebud_infowindow.find(".estatebud-infowindow-slider").slick({
                    speed: 1,
                    arrows: false
                });
            }
        }
    });
}

function estatebud_prepareForDeletion() {
    if (estatebud.groupMarkers && estatebud_markerClusterer) {
        estatebud_markerClusterer.clearMarkers();
    }
    estatebud_markers.map(function (marker) {
        marker.delete = true;
    });
}

function estatebud_clearExtraMarkers() {
    for (var i = 0; i < estatebud_markers.length; i++) {
        if (estatebud_markers[i].delete === true) {
            estatebud_markers[i].setMap(null);
            estatebud_markers[i] = null;
        }
    }
    estatebud_markers = estatebud_markers.filter(function (obj) { return obj; });
}

function estatebud_getIconColor(property_type) {
    switch (property_type) {
        case "":
        case "detached_villa":
        case "detached_house":
        case "semi_detached_villa":
        case "semi_detached_house":
        case "link_detached_villa":
        case "link_detached_house":
        case "villa":
        case "house":
        case "house_of_character":
		case "finca":
        case "bungalow":
        case "detached_bungalow":
        case "semi_detached_bungalow":
		case "barn_conversion":
		case "country_house":
		case "cottage":
		case "lodge":
		case "chalet":
		case "chateau":
		case "palazzo":
		case "longere":
		case "cluster_house":
		case "mews_house":
		case "riad":
		case "mobile_park_home":
		case "houseboat":
		case "terraced_bungalow":
        case "terraced_house":
		case "townhouse":
            return "00822e";
        case "flat":
        case "apartment":
		case "maisonette":
		case "quadplex":
		case "duplex":
		case "duplex_maisonette":
		case "condominium":
            return "bf52a0";
		case "farm":
		case "farmhouse":
		case "equestrian_property":
            return "28a5a5";
        case "building_plot":
        case "development_land":
        case "field":
		case "island":
            return "d83205";
		case "garage":
        case "parking_space":
		case "boat_house":
        case "office":
        case "hotel":
        case "shop":
        case "warehouse":
        case "industrial_building":
        case "commercial_building":
        case "apartment_building":
        case "showroom":
        case "block_of_apartments":
		case "mixed_use":
		case "restaurant":
		case "cafe":
		case "bar":
		case "pub":
		case "retail_premises":
		case "light_industrial":
		case "student_accommodation":
		case "leisure_hospitality":
		case "yard":
		case "business_park":
            return "394675";
    }

}

function estatebud_getMarkerIcon(property_type) {
    var sizeX = 38;
    var sizeY = 46.04;
	var url = '';
	
    switch (property_type) {
        case "":
        case "detached_villa":
        case "detached_house":
        case "semi_detached_villa":
        case "semi_detached_house":
        case "link_detached_villa":
        case "link_detached_house":
        case "villa":
        case "house":
		case "finca":
        case "bungalow":
        case "detached_bungalow":
        case "semi_detached_bungalow":
		case "house_of_character":
		case "barn_conversion":
		case "country_house":
		case "cottage":
		case "lodge":
		case "chalet":
		case "chateau":
		case "palazzo":
		case "longere":
		case "cluster_house":
		case "mews_house":
		case "riad":
            url = estatebud_pluginPath + "house.svg?" + estatebud.version;
            break;
		case "boat_house":
            url = estatebud_pluginPath + "boat-house.svg?" + estatebud.version;
            break;
		case "mobile_park_home":
            url = estatebud_pluginPath + "mobile-park-home.svg?" + estatebud.version;
            break;
		case "houseboat":
            url = estatebud_pluginPath + "houseboat.svg?" + estatebud.version;
            break;
		case "farm":
		case "farmhouse":
		case "equestrian_property":
			url = estatebud_pluginPath + "farm.svg?" + estatebud.version;
            break;
        case "townhouse":
        case "terraced_bungalow":
        case "terraced_house":
		case "maisonette":
		case "quadplex":
		case "duplex":
		case "duplex_maisonette":
            url = estatebud_pluginPath + "townhouse.svg?" + estatebud.version;
            break;
        case "flat":
        case "apartment":
		case "condominium":
            url = estatebud_pluginPath + "apartment.svg?" + estatebud.version;
            break;
        case "garage":
            url = estatebud_pluginPath + "garage.svg?" + estatebud.version;
            break;
        case "parking_space":
            url = estatebud_pluginPath + "parking-space.svg?" + estatebud.version;
            break;
        case "building_plot":
        case "development_land":
        case "field":
		case "island":
            url = estatebud_pluginPath + "land.svg?" + estatebud.version;
            break;
        case "office":
		case "commercial_building":
		case "apartment_building":
		case "block_of_apartments":
            url = estatebud_pluginPath + "building.svg?" + estatebud.version;
            break;
        case "showroom":
		case "shop":
		case "retail_premises":
            url = estatebud_pluginPath + "shop-2.svg?" + estatebud.version;
            break;
		case "mixed_use":
		case "yard":
		case "business_park":
            url = estatebud_pluginPath + "commercial.svg?" + estatebud.version;
            break;
		case "warehouse":
            url = estatebud_pluginPath + "warehouse.svg?" + estatebud.version;
            break;
		case "hotel":
		case "student_accommodation":
		case "leisure_hospitality":
            url = estatebud_pluginPath + "hotel.svg?" + estatebud.version;
            break;
		case "industrial_building":
		case "light_industrial":
            url = estatebud_pluginPath + "industry.svg?" + estatebud.version;
            break;
		case "restaurant":
		case "cafe":
		case "bar":
		case "pub":
            url = estatebud_pluginPath + "shop.svg?" + estatebud.version;
            break;
    }
	
	return {
		url: url,
		size: new google.maps.Size(sizeX, sizeY),
		origin: new google.maps.Point(0, 0),
		anchor: new google.maps.Point((sizeX/2), sizeY),
		scaledSize: new google.maps.Size(sizeX, sizeY)
	};
}

function estatebud_getMarkerLabel(property_type, location) {
    // find all markers on that location
    var same_spot_markers = estatebud_markers.filter(function (m) {
        return m.getPosition().equals(location);
    });

    // remove previous markers' labels
    same_spot_markers.map(function (marker) {
        marker.set("visible", false);
    });
	
    if (same_spot_markers.length > 0) {
        var backcolor = estatebud_getIconColor(property_type);
        return {
			raiseOnDrag: true,
            labelContent: (same_spot_markers.length + 1).toString(),
            labelClass: "estatebud-marker-label estatebud-marker-label-" + backcolor,
            labelAnchor: new google.maps.Point(10, -50),
            labelInBackground: false
        };
    } else {
        return {
			raiseOnDrag: true,
            labelContent: "",
            labelAnchor: new google.maps.Point(0, 0),
            labelInBackground: false
        };
    }
}

function estatebud_toggleAutoFilterSwitch(check) {
    estatebud_autoFilter = check.checked;
    if (estatebud_autoFilter) {
        document.getElementById("estatebud_filter_form_button").style.display = "none";
    } else {
        document.getElementById("estatebud_filter_form_button").style.display = "inline-block";
    }
}

function estatebud_submitMapFilterForm() {
    if (estatebud_autoFilter == false) {
        estatebud_skipRefresh = false;
        google.maps.event.trigger(estatebud_map, "bounds_changed");
    }
    return false;
}

(function ($) {
    $(document).ready(function () {
        $(".estatebud-filter-button").on("click.estatebud", function () {
            $(".estatebud-shortcode-filters").toggleClass("estatebud-show");
        });
        jQuery(".sumo-input").SumoSelect();
    });

    $(document).on("mouseover", ".estatebud-property", function () {
        var id = $(this).data("id");
        estatebud_markers.map(function (marker) {
            if (marker.property_id == id) {
                marker.setAnimation(google.maps.Animation.BOUNCE);
            }
        });
    });

    $(document).on("mouseout", ".estatebud-property", function () {
        estatebud_markers.map(function (marker) {
            marker.setAnimation(null);
        });
    });

    $(document).on("click", ".estatebud-infowindow-close", function () {
        estatebud_unslick();
    });

})(jQuery);
