<?php
function estatebud_generate_property_list_entry($estatebud_api, $details, $params = array())
{
	$estatebud_rental_availability_days = get_option('estatebud_rental_availability_days', "30");
	$link = estatebud_get_property_link($details);
	$location = trim(estatebud_get_locations_details($details));

	$tags = "";
	if(property_exists($details, "originalprice")) $tags .= "<div class='estatebud-property-tag estatebud-property-tag-reduced'>".estatebud__("app.reduced.price")."</div>&nbsp;";
	if(property_exists($details, "labels")){
		foreach($details->labels as $label){
			if($label->public){
				$tags .= "<div class='estatebud-property-tag' style='background: #$label->color'>".estatebud__($label->name)."</div>&nbsp;";
			}
		}
	}
	$tags = trim($tags);

	$aTarget = "";
	if(isset($params['open_new_tab'])) {
		$aTarget = ' target="_blank"';
	}

	$html = '<div class="estatebud-column">
				<a href="'.$link.'"'.$aTarget.'>
					<div class="estatebud-property">
						<div class="estatebud-property-block-image">
							<div class="estatebud-property-image">';

	if(property_exists($details, "buyer")) {
		$html .= '<div class="estatebud-property-sold">'.estatebud__("app.sold").'</div>';
	}

	if(property_exists($details, "tenant")) {
		if(time() < strtotime($details->tenant->period_to) - ($estatebud_rental_availability_days * 86400)) {
			$html .= '<div class="estatebud-property-rented">'.estatebud__("app.rented").'</div>';
		}
	}
	
	$thumb="";
	if(property_exists($details, "images") && count($details->images) > 0) {
		foreach($details->images AS $image) {
			if($image->status != '1') { continue; }
			$thumb=$image->thumb;
			break;
		}
	}
	
	if($thumb != '') {
    	$html .= '<img src="'.$thumb.'" />';
	} else {
		$placeholder = get_option("estatebud_placeholder_image", false);
		if($placeholder === false) {
			$placeholder = plugin_dir_url(__FILE__) . "../assets/placeholder.jpg";
		}
		$html .= '<img src="'.$placeholder.'" />';
	}

	$html .= '              </div>
					    </div>
						<div class="estatebud-property-block-info">
							'.estatebud_get_property_title($details).'
							<div class="estatebud-property-location">'.$location.'</div>';

	if($tags != "") {
		$html .= '<div class="estatebud-property-tags">'.$tags.'</div>';
	}

	$html .= '          	<div class="estatebud-property-price-info">
								'.estatebud_get_currency_details($estatebud_api, $details).'
							</div>
							<div class="estatebud-property-footer">
								<div class="estatebud-property-attrs">';

    if(property_exists($details, "category") && $details->category != "land") {
		if(property_exists($details, "category") && $details->category != "com_sale" && $details->category != "com_rent_long") {
			if(property_exists($details, "data") && property_exists($details->data, "bedrooms")) {
				$html .= '      	<div class="estatebud-property-attr">
										<i class="fas fa-bed"></i>'.($details->data->bedrooms == 0 ? estatebud__("app.property.studio") : intval($details->data->bedrooms)).'
									</div>';
			}

			if(property_exists($details, "data") && property_exists($details->data, "bathrooms")) {
				$html .= '     		<div class="estatebud-property-attr">
										<i class="fas fa-bath"></i>'.intval($details->data->bathrooms).'
									</div>';
			}
		}

		if(property_exists($details, "areas") && property_exists($details->areas, "coveredm2")) {
                $html .= '      	<div class="estatebud-property-attr">
										<i class="fas fa-expand-arrows-alt"></i>'.intval($details->areas->coveredm2->value).' m²
									</div>';
        }
    } else {
		if(property_exists($details, "areas") && property_exists($details->areas, "plotm2")) {
            $html .= '         		<div class="estatebud-property-attr">
										<i class="fas fa-expand-arrows-alt"></i>'.intval($details->areas->plotm2->value).' m²
									</div>';
		}
	}

	$html .= '             		</div>

								<div class="estatebud-property-price estatebud-price-plus">
									<i class="fas fa-plus"></i>
								</div>
							</div>
						</div>
					</div>
				</a>
			</div>';

	return $html;
}

function estatebud_generate_property_list_slider_entry($estatebud_api, $details, $slider_template, $params = array())
{
    $template_to_load = plugin_dir_path(__FILE__) . '../../includes/slider/' . $slider_template . '.php';

    $property_title =  estatebud_get_property_title($details);
	$property_link = estatebud_get_property_link($details);
    $property_location = trim(estatebud_get_locations_details($details));
    $property_price = estatebud_get_currency_details($estatebud_api, $details);
    $property_image_thumb = get_option("estatebud_placeholder_image", plugin_dir_url(__FILE__) . "../assets/placeholder.jpg");
    $property_image_hd1080 = get_option("estatebud_placeholder_image", plugin_dir_url(__FILE__) . "../assets/placeholder.jpg");
	
	if(property_exists($details, "images") && count($details->images) > 0) {
		foreach($details->images AS $image) {
			if($image->status != '1') { continue; }
			$property_image_thumb=$image->thumb;
			$property_image_hd1080=$image->hd1080;
			break;
		}
	}
	
    $property_tags = [];
    if(property_exists($details, "originalprice")){
        $property_tags[] = [
            "extra_classes" => "estatebud-property-tag-reduced",
            "color" => "",
            "label" => estatebud__("app.reduced.price")
        ];
    }

	if(property_exists($details, "labels")){
		foreach($details->labels as $label){
			if($label->public){
                $property_tags[] = [
                    "extra_classes" => "",
                    "color" => $label->color,
                    "label" => estatebud__($label->name)
                ];
            }
        }
    }

	$aTarget = "";
	if(isset($params['open_new_tab'])) {
		$aTarget = ' target="_blank"';
    }

    $property_labels = [];
	if(property_exists($details, "buyer")) {
        $property_labels[] = [
            "class" => "estatebud-property-sold",
            "label" => estatebud__("app.sold")
        ];
	}

	if(property_exists($details, "tenant")) {
        $property_labels[] = [
            "class" => "estatebud-property-rented",
            "label" => estatebud__("app.rented")
        ];
	}

    $property_attributes = [];

    if(property_exists($details, "category") && $details->category != "land") {
		if(property_exists($details, "category") && $details->category != "com_sale" && $details->category != "com_rent_long") {
			if(property_exists($details, "data") && property_exists($details->data, "bedrooms")) {
                $property_attributes[] = [
                    "label" => ($details->data->bedrooms == 0 ? estatebud__("app.property.studio") : intval($details->data->bedrooms)),
                    "icon" => "fas fa-bed"
                ];
			}

			if(property_exists($details, "data") && property_exists($details->data, "bathrooms")) {
                $property_attributes[] = [
                    "label" => intval($details->data->bathrooms),
                    "icon" => "fas fa-bath"
                ];
			}
		}

		if(property_exists($details, "areas") && property_exists($details->areas, "coveredm2")) {
            $property_attributes[] = [
                "label" => intval($details->areas->coveredm2->value).' m²',
                "icon" => "fas fa-expand-arrows-alt"
            ];
        }
    } else {
		if(property_exists($details, "areas") && property_exists($details->areas, "plotm2")) {
            $property_attributes[] = [
                "label" => intval($details->areas->plotm2->value).' m²',
                "icon" => "fas fa-expand-arrows-alt"
            ];
		}
    }
    require $template_to_load;
}

function estatebud_get_translation_details($object, $dontUseEnglish = false)
{
    if (!$object) return "";
    $locale = str_replace("_", "-", isset($_GET["lang"]) ? $_GET["lang"] : get_locale());
    if ($locale == 'el') {
        $locale = "el-GR";
    }
    if (property_exists($object, $locale))
        return $object->{$locale};
    else if (property_exists($object, explode("-", $locale)[0]))
        return $object->{explode("-", $locale)[0]};
    else if ($dontUseEnglish)
        return false;
    else if (estatebud__($object->value) && estatebud__($object->value) != $object->value)
        return estatebud__($object->value);
    else
        return $object->value;
}

function estatebud_get_property_link($object)
{
    $property_page_id = get_option("estatebud_property_page_id", null);
    if($property_page_id){
        if ( function_exists('icl_object_id') ) {
            $property_page_id =  apply_filters( 'wpml_object_id', $property_page_id, 'post' );
        }
        $page = get_post($property_page_id);
        if($page instanceof WP_Post){
            $page_slug = $page->post_name;
            if(get_option("estatebud_pretty_permalinks", false) == false){
                return rtrim(home_url( $page_slug ), "/") . "-" . $object->reference_id;
            }else{
                return rtrim(home_url( $page_slug ), "/") . "-" . $object->reference_id . "/" . sanitize_title_with_dashes( estatebud_get_property_title($object) );
            }
        }
    }
}

function estatebud_get_property_title($object)
{
    $title = false;
    if (property_exists($object, "title")) {
        $title = estatebud_get_translation_details($object->title, true);
    }
    if ($title == false) {
        if (property_exists($object, "category")) {
            $category = $object->category;
            $property_type = null;
            $title = "";
            if (property_exists($object, "type") && property_exists($object->type, "translations")) {
                $property_type = estatebud_get_translation_details($object->type->translations);
            }
            if ($category == "res_rent_short" || $category == "res_rent_long" || $category == "res_sale") {
                if (property_exists($object, "data") && property_exists($object->data, "bedrooms")) {
                    $title = sprintf(
						estatebud__("app.property.title", $object->data->bedrooms),
                        $object->data->bedrooms,
                        $property_type
                    );
                } else {
                    $title = $property_type;
                }
            } else if ($category == "com_sale" || $category == "com_rent_long") {
                $title = $property_type ? $property_type : estatebud__("app.commercial.property");
            } else if ($category == "land") {
                $title = $property_type ? $property_type : estatebud__("app.land");
            } else {
                $title = "";
            }

			$title = mb_strtoupper($title[0], 'UTF-8').mb_substr(mb_strtolower($title, 'UTF-8'), 1);
        } else {
            $title = "";
        }
    }
    $title = trim($title);
    return $title != "" ? "<div class='estatebud-property-title'>$title</div>" : "<div class='estatebud-property-title'></div>";
}

function estatebud_get_locations_details($object)
{
    $areas = [
        property_exists($object, "area1_name") ? $object->area1_name : null,
        property_exists($object, "area2_name") ? $object->area2_name : null,
        property_exists($object, "area3_name") ? $object->area3_name : null
    ];
    $areas = array_filter($areas);
    if (count($areas) > 1) {
        return implode(", ", array_slice($areas, -2, 2));
    } else if (count($areas)) {
        return $areas[0];
    } else {
        return "";
    }
}

function estatebud_remove_parenthesis($string)
{
    return preg_replace("/\s+\([^)]+\)/i", "", $string);
}

function estatebud_get_currency_details($estatebud_api, $data)
{
    $currency = $estatebud_api->auth_info->currency;

    if (property_exists($data, "category") == false) {
        if (property_exists($data, "rent")) $type = "rent";
        else if (property_exists($data, "price")) $type = "price";
        else $type = null;
    } else {
        $type = in_array($data->category, ["res_rent_long", "res_rent_short", "com_rent_long"]) ? "rent" : "price";
    }
    $price = null;
    if ($type == "rent") {
        if (property_exists($data, "rent")) $price = $data->rent;
    } else {
        if (property_exists($data, "price")) $price = $data->price;
    }
    if($type == "rent")
        $original = property_exists($data, "originalrent") ? $data->originalrent : null;
    else
        $original = property_exists($data, "originalprice") ? $data->originalprice : null;
    if ($price && property_exists($price, $currency)) {
        $result = "<div>";
        $result .= estatebud_build_price($price->{$currency}, $currency, $estatebud_api);
        if ($original && property_exists($original, $currency)) {
            $result .= "<strike style='margin-right: 0'>" . estatebud_build_price($original->{$currency}, $currency, $estatebud_api) . "</strike>";
        }
        $result .= "</div>";
        if ($type == "rent") {
			if($data->category == 'res_rent_short') {
				if(property_exists($data, "data") && property_exists($data->data, "rentfrequency")) {
					if($data->data->rentfrequency == 'night') {
						$rent_frequency=estatebud__("app.night");
					} elseif($data->data->rentfrequency == 'week') {
						$rent_frequency=estatebud__("app.week");
					} elseif($data->data->rentfrequency == 'month') {
						$rent_frequency=estatebud__("app.month");
					} elseif($data->data->rentfrequency == 'year') {
						$rent_frequency=estatebud__("app.year");
					}
				} else {
					$rent_frequency=estatebud__("app.night");
				}
			} else {
				$rent_frequency=estatebud__("app.month");
			}
			
			$result .= "<span class='estatebud-property-rent-month'>&nbsp;/&nbsp;" . $rent_frequency . "</span>";
        }
        if (property_exists($price->{$currency}, "vat") && $price->{$currency}->vat == 1) {
            $result .= "<small>" . estatebud__("app.plus.taxes") . "</small>";
        }
        return $result;
    } else {
        return estatebud__("app.price.request");
    }
}

function estatebud_show_currency_select($currencies, $default_currency, $global = false)
{
    echo '<select class="sumo-input" onchange="estatebudChangeCurrency(this, ' . ( $global ? 'true' : 'false' ) . ');" style="width: 100%;">';
        foreach($currencies as $currency) :
            echo "<option value='$currency'" . ($default_currency == $currency ? "selected='selected'" : "" ) . ">$currency</option>";
        endforeach;
    echo '</select>';
}

function estatebud_build_price($value, $currency, $estatebud_api)
{
    if(isset($_COOKIE["estatebud_selected_currency"])){
        if($_COOKIE["estatebud_selected_currency"] != strtoupper($currency)){
            $target = $_COOKIE["estatebud_selected_currency"];
	        $rates = $estatebud_api->get_currency_rates();
		    $target_rate = $rates->rates->{$target} / $rates->rates->{strtoupper($currency)};
            $amount = intval($value->amount) * $target_rate;
            $details = $rates->exchange_rates->{$target}->details;
            $result = "<span class='estatebud-currency-container' data-start-currency='$currency' data-start-value='$value->amount'>";
            if($details->symbol_prefix){
                $result .= $details->symbol;
                if($details->symbol_space){
                    $result .= " ";
                }
            }
            $result .= number_format($amount, 0, trim($details->decimal_separator) ? $details->decimal_separator : ",", $details->thousand_separator);
            if($details->symbol_prefix == false){
                if($details->symbol_space){
                    $result .= " ";
                }
                $result .= $details->symbol;
            }
            $result .= "</span>";
            return $result;
        }
    }

    $result = "<span class='estatebud-currency-container' data-start-currency='$currency' data-start-value='$value->amount'>";
    if (property_exists($value, "details")) {
        if ($value->details->dir == "left") {
            $result .= $value->details->symbol;
            if ($value->details->space) $result .= " ";
        }
    }
    if (property_exists($value, "amount")) {
        $result .= number_format($value->amount);
        if (property_exists($value, "details")) {
            if ($value->details->dir == "right") {
                if ($value->details->space) $result .= " ";
                $result .= $value->details->symbol;
            }
        }
    }
    return $result . "</span>";
}

function estatebud_get_distance_icon($key)
{
    switch ($key) {
        case "distancetoamenitieskm":
            return "<i class='fas fa-shopping-basket'></i>";
        case "distancetoairportkm":
            return "<i class='fas fa-plane'></i>";
        case "distancetoseakm":
            return "<i class='fas fa-swimmer'></i>";
        case "distancetoresortkm":
            return "<i class='fas fa-home'></i>";
        case "distancetoschoolskm":
            return "<i class='fas fa-graduation-cap'></i>";
        case "distancetotransitkm":
            return "<i class='fas fa-bus'></i>";
    }
    return "";
}

function estatebud_get_distance_km($km)
{
    if ($km < 1) {
        return round($km * 1000) . " m";
    }
    return $km . " km";
}


function estatebud_property_infos($estatebud_api, $details)
{
    if(property_exists($details, "data")){
        if (property_exists($details->data, "bedrooms")) : ?><div class="estatebud-property-info"><i class="fas fa-bed"></i><b><?php echo estatebud__("app.bedroom", 2); ?>:</b> <?php if($details->data->bedrooms == 0) { echo __("Studio", "estatebud"); } else { echo $details->data->bedrooms; } ?></div><?php endif;
        if (property_exists($details->data, "bathrooms")) : ?><div class="estatebud-property-info"><i class="fas fa-bath"></i><b><?php echo estatebud__("app.bathroom", 2); ?>:</b> <?php echo $details->data->bathrooms; ?></div><?php endif;
        if (property_exists($details->data, "toilets")) : ?><div class="estatebud-property-info"><i class="fas fa-toilet"></i><b><?php echo estatebud__("app.toilet", 2); ?>:</b> <?php echo $details->data->toilets; ?></div><?php endif;
        if (property_exists($details->data, "showers")) : ?><div class="estatebud-property-info"><i class="fas fa-shower"></i><b><?php echo estatebud__("app.shower", 2); ?>:</b> <?php echo $details->data->showers; ?></div><?php endif;
        if (property_exists($details->data, "livingrooms")) : ?><div class="estatebud-property-info"><i class="fas fa-home"></i><b><?php echo estatebud__("app.living.room", 2); ?>:</b> <?php echo $details->data->livingrooms; ?></div><?php endif;
        if (property_exists($details->data, "kitchens")) : ?><div class="estatebud-property-info"><i class="fas fa-coffee"></i><b><?php echo estatebud__("app.kitchen", 2); ?>:</b> <?php echo $details->data->kitchens; ?></div><?php endif;
        if (property_exists($details->data, "rooms")) : ?><div class="estatebud-property-info"><i class="fas fa-building"></i><b><?php echo estatebud__("app.room", 2); ?>:</b> <?php echo $details->data->rooms; ?></div><?php endif;
        if (property_exists($details, "facilities") && property_exists($details->facilities, "pool")) : ?><div class="estatebud-property-info"><i class="fas fa-swimming-pool"></i><b><?php echo estatebud__("app.pool"); ?>:</b> <?php echo $details->facilities->pool->value; ?></div><?php endif;
        if (property_exists($details, "floor")) : ?><div class="estatebud-property-info"><i class="fas fa-building"></i><b><?php echo estatebud__("app.floor"); ?>:</b> <?php echo estatebud_get_translation_details($details->floor->translations); ?></div><?php endif;
        if (property_exists($details->data, "floors")) : ?><div class="estatebud-property-info"><i class="fas fa-building"></i><b><?php echo estatebud__("app.floor", 2); ?>:</b> <?php echo $details->data->floors; ?></div><?php endif;
        if (property_exists($details->data, "constructionyear")) : ?><div class="estatebud-property-info"><i class="fas fa-tools"></i><b><?php echo estatebud__("app.construction.year"); ?>:</b> <?php echo $details->data->constructionyear; ?></div><?php endif;
        if (property_exists($details->data, "renovationyear")) : ?><div class="estatebud-property-info"><i class="fas fa-tools"></i><b><?php echo estatebud__("app.renovation.year"); ?>:</b> <?php echo $details->data->renovationyear; ?></div><?php endif;
        if (property_exists($details, "orientation")) : ?><div class="estatebud-property-info"><i class="fas fa-compass"></i><b><?php echo estatebud__("app.orientation"); ?>:</b> <?php echo estatebud_get_translation_details($details->orientation->translations); ?></div><?php endif;
        if (property_exists($details, "furnished")) : ?><div class="estatebud-property-info"><i class="fas fa-bed"></i><b><?php echo estatebud__("app.furnished"); ?>:</b> <?php echo estatebud_get_translation_details($details->furnished->translations); ?></div><?php endif;
        if (property_exists($details->data, "parkingspaces")) : ?><div class="estatebud-property-info"><i class="fas fa-car"></i><b><?php echo estatebud__("app.parking.space", 2); ?>:</b> <?php echo $details->data->parkingspaces; ?></div><?php endif;
        if (property_exists($details, "basement")) : ?><div class="estatebud-property-info"><i class="fas fa-caret-square-o-down"></i><b><?php echo estatebud__("app.basement"); ?>:</b> <?php echo estatebud_get_translation_details($details->basement->translations); ?></div><?php endif;
        if (property_exists($details, "status")) : ?><div class="estatebud-property-info"><i class="fas fa-home"></i><b><?php echo estatebud__("app.status"); ?>:</b> <?php echo estatebud_get_translation_details($details->status->translations); ?></div><?php endif;
        if (property_exists($details, "structure")) : ?><div class="estatebud-property-info"><i class="fas fa-home"></i><b><?php echo estatebud__("app.structure"); ?>:</b> <?php echo estatebud_get_translation_details($details->structure->translations); ?></div><?php endif;
        if (property_exists($details, "facade")) : ?><div class="estatebud-property-info"><i class="fas fa-home"></i><b><?php echo estatebud__("app.facade"); ?>:</b> <?php echo estatebud_get_translation_details($details->facade->translations); ?></div><?php endif;
        if (property_exists($details, "framestype")) : ?><div class="estatebud-property-info"><i class="fas fa-home"></i><b><?php echo estatebud__("app.frames.type"); ?>:</b> <?php echo estatebud_get_translation_details($details->framestype->translations); ?></div><?php endif;
        if (property_exists($details->data, "energyefficiencyrating")) : ?><div class="estatebud-property-info"><i class="fas fa-leaf"></i><b><?php echo estatebud__("app.energy.efficiency.rating"); ?>:</b> <?php echo $details->data->energyefficiencyrating; ?></div><?php endif;
        if (property_exists($details, "titledeed")) : ?><div class="estatebud-property-info"><i class="fas fa-file"></i><b><?php echo estatebud__("app.title.deed"); ?>:</b> <?php echo estatebud_get_translation_details($details->titledeed->translations); ?></div><?php endif;
	}
    if (property_exists($details, "communal_charge") && property_exists($details->communal_charge, $estatebud_api->auth_info->currency)) : ?><div class="estatebud-property-info"><i class="fas fa-coins"></i><b><?php echo estatebud__("app.communal.expense"); ?>:</b> <?php echo estatebud_build_price($details->communal_charge->{$estatebud_api->auth_info->currency}, $estatebud_api->auth_info->currency, $estatebud_api); ?></div><?php endif;

    if ($estatebud_api->auth_info->measurements == "imperial") :
        estatebud_property_info_area($details, "coveredft2", "fas fa-expand-arrows-alt", "ft²");
        estatebud_property_info_area($details, "plotft2", "fas fa-expand", "ft²");
        estatebud_property_info_area($details, "uncoveredverandaft2", "fas fa-arrows-alt", "ft²");
        estatebud_property_info_area($details, "coveredverandaft2", "fas fa-arrows-alt", "ft²");
        estatebud_property_info_area($details, "basementft2", "fas fa-arrows-alt", "ft²");
        estatebud_property_info_area($details, "roofgardenft2", "fas fa-arrows-alt", "ft²");
    else :
        estatebud_property_info_area($details, "coveredm2", "fas fa-expand-arrows-alt", "m²");
        estatebud_property_info_area($details, "plotm2", "fas fa-expand", "m²");
        estatebud_property_info_area($details, "uncoveredverandam2", "fas fa-arrows-alt", "m²");
        estatebud_property_info_area($details, "coveredverandam2", "fas fa-arrows-alt", "m²");
        estatebud_property_info_area($details, "basementm2", "fas fa-arrows-alt", "m²");
        estatebud_property_info_area($details, "roofgardenm2", "fas fa-arrows-alt", "m²");
    endif;
}

function estatebud_property_info_area($details, $key, $icon, $suffix)
{
    if (property_exists($details, "areas") && property_exists($details->areas, $key)) {
        echo "<div class=\"estatebud-property-info\"><i class=\"$icon\"></i><b>" . estatebud_get_translation_details($details->areas->{$key}->translations) . ":</b>";
        echo $details->areas->{$key}->value . $suffix . "</div>";
    }
}

if(isset($details)) {
	echo '<script>var estatebud_property_id = "'.$details->reference_id.'";</script>';
}
?>
